@@ -76,7 +76,7 @@ final class Products extends CGExtensions
   public function AllowAutoUpgrade() { return FALSE; }
   public function IsPluginModule() { return true; }
   public function HasAdmin() {	return true; }
-  public function GetVersion() { return '2.19.8'; }
+  public function GetVersion() { return '2.20'; }
   public function MinimumCMSVersion() { return '1.11.8'; }
   public function GetAdminDescription() { return $this->Lang('module_description'); }
   public function UninstallPostMessage() { return $this->Lang('postuninstall'); }
@@ -96,9 +96,7 @@ final class Products extends CGExtensions
 
   function GetDependencies()
   {
-	return array('CGExtensions'=>'1.32.5',
-				 'CGSimpleSmarty'=>'1.6.1',
-				 'JQueryTools'=>'1.2.4');
+	return array('CGExtensions'=>'1.37.3', 'CGSimpleSmarty'=>'1.6.1', 'JQueryTools'=>'1.2.4');
   }
 
   function VisibleToAdminUser()
@@ -113,7 +111,7 @@ final class Products extends CGExtensions
 	$obj = cge_utils::get_module('JQueryTools','1.2');
     if( is_object($obj) ) {
 $tmpl = <<<EOT
-{JQueryTools action='require' lib='tablesorter,jquerytools'}
+{JQueryTools action='require' lib='tablesorter,jquerytools,fancybox'}
 {JQueryTools action='placemarker'}
 EOT;
         return $this->ProcessTemplateFromData($tmpl);
@@ -340,19 +338,13 @@ EOT;
 	return $results;
   }
 	
-  // deprecated
-  function GetFieldDefs($admin = false,$public = true)
-  {
-	return product_utils::get_fielddefs($admin,$public);
-  }
-
   // deprecated, move to class
   function GetFieldDefsForProduct($id,$admin = false,$public = true)
   {
 	$gCms = cmsms();
 	$db = $gCms->GetDB();
 
-	$entryarray = $this->GetFieldDefs($admin,$public);
+	$entryarray = product_utils::get_fielddefs($admin,$public);
 
 	$query = '';
 	if( $admin == true && $public == true ) {
@@ -460,13 +452,12 @@ EOT;
 	$db = cmsms()->GetDb();
 
 	// convert names to category ids.
-	$query = 'SELECT id FROM '.cms_db_prefix().'module_products_categories
-               WHERE name IN ('.implode(',',$names).')';
+	$query = 'SELECT id FROM '.cms_db_prefix().'module_products_categories WHERE name IN ('.implode(',',$names).')';
 	$categories = $db->GetCol($query);
 	if( !$categories ) return FALSE;
 	
-	$query = 'SELECT product_id FROM '.cms_db_prefix().'module_products_product_categories
-               WHERE category_id IN ('.implode(',',$categories).')';
+	$query = 'SELECT product_id FROM '.cms_db_prefix().'module_products_product_categories 
+              WHERE category_id IN ('.implode(',',$categories).')';
 	$products = $db->GetCol($query);
 	return $products;
   }
@@ -483,21 +474,18 @@ EOT;
 	$hierarchies = array();
 	if( endswith($hier_str,'*') ) {
 	  $hier_str = str_replace('*','%',$hier_str);
-	  $query = 'SELECT id FROM '.cms_db_prefix().'module_products_hierarchy 
-                WHERE upper(long_name) LIKE upper(?)';
+	  $query = 'SELECT id FROM '.cms_db_prefix().'module_products_hierarchy WHERE upper(long_name) LIKE upper(?)';
 	  $hierarchies = $db->GetCol($query,array($hier_str));
 	}
 	else {
-	  $query = 'SELECT id FROM '.cms_db_prefix().'module_products_hierarchy
-                WHERE upper(long_name) = upper(?)';
+	  $query = 'SELECT id FROM '.cms_db_prefix().'module_products_hierarchy WHERE upper(long_name) = upper(?)';
 	  $hier_id = $db->GetOne($query,array($hier_str));
 	  if( !$hier_id ) return FALSE;
 	  $hierarchies[] = $hier_id;
 	}
 
 	$tmp = implode(',',$hierarchies);
-	$query = 'SELECT product_id FROM '.cms_db_prefix()."module_products_prodtohier
-                 WHERE hierarchy_id IN ($tmp)";
+	$query = 'SELECT product_id FROM '.cms_db_prefix()."module_products_prodtohier WHERE hierarchy_id IN ($tmp)";
 	$products = $db->GetCol($query);
 	return $products;
   }
