@@ -37,105 +37,58 @@
 #-------------------------------------------------------------------------
 #END_LICENSE
 if (!isset($gCms)) exit;
+if (!$this->CheckPermission('Modify Products')) return;
 
 $this->SetCurrentTab('fielddefs');
-if (!$this->CheckPermission('Modify Products'))
-{
-	echo $this->ShowErrors($this->Lang('needpermission', array('Modify Products')));
-	return;
-}
-
-if (isset($params['cancel']))
-{
-  $this->RedirectToTab($id);
-}
-
-$name = '';
-if (isset($params['name']))
-{
-	$name = $params['name'];
-}
-
-$prompt = '';
-if (isset($params['prompt']))
-{
-	$prompt = $params['prompt'];
-}
-
-$options = '';
-if (isset($params['options']))
-{
-  $options = trim($params['options']);
-}
-
-$type = '';
-if (isset($params['type']))
-{
-	$type = $params['type'];
-}
-
-$max_length = 255;
-if (isset($params['max_length']))
-{
-  $max_length = (int)$params['max_length'];
-}
-
-$public = 1;
-if( isset($params['public']) )
-  {
-    $public = (int)$params['public'];
-  }
+if (isset($params['cancel']))  $this->RedirectToTab($id);
 
 $userid = get_userid();
+$name = trim(get_parameter_value($params,'name'));
+$prompt = trim(get_parameter_value($params,'prompt'));
+$options = trim(get_parameter_value($params,'options'));
+$type = trim(get_parameter_value($params,'type'));
+$max_length = (int)get_parameter_value($params,'max_length');
+$public = (int)get_parameter_value($params,'public',1);
 
-if (isset($params['submit']))
-{
-  if( $type == '' )
-    {
-      echo $this->ShowErrors($this->Lang('error_nofieldtype'));
+if (isset($params['submit'])) {
+  if( $type == '' ) {
+    echo $this->ShowErrors($this->Lang('error_nofieldtype'));
+  }
+  else if ($name == '') {
+    echo $this->ShowErrors($this->Lang('nonamegiven'));
+  }
+  else if( !$this->is_alias($name) ) {
+    echo $this->ShowErrors($this->Lang('error_invalid_name'));
+  }
+  else if( !empty($max_length) && !is_numeric($max_length) ) {
+    echo $this->ShowErrors($this->Lang('notanumber'));
+  }
+  else if( $type == 'subscription' && 
+	   $db->GetOne('SELECT id FROM '.cms_db_prefix().'module_products_fielddefs WHERE type = ?',array($type)) ) {
+    echo $this->ShowErrors($this->Lang('error_onesubscriptionfield'));
+  }
+  else if( $type == 'quantity' && 
+	   $db->GetOne('SELECT id FROM '.cms_db_prefix().'module_products_fielddefs WHERE type = ?',array($type)) ) {
+    echo $this->ShowErrors($this->Lang('error_onequantityfield'));
+  }
+  else {
+    $max = $db->GetOne('SELECT max(item_order) + 1 FROM ' . cms_db_prefix() . 'module_products_fielddefs');
+    if( !$max ) $max = 0;
+    $query = 'INSERT INTO '.cms_db_prefix().'module_products_fielddefs (name, prompt, type, max_length, item_order, create_date, modified_date, public, options) VALUES (?,?,?,?,?,?,?,?,?)';
+    $parms = array($name, $prompt, $type, $max_length, $max, 
+		   trim($db->DBTimeStamp(time()), "'"), trim($db->DBTimeStamp(time()), "'"), $public,$options);
+    $dbr = $db->Execute($query, $parms );
+    if( !$dbr ) {
+      echo "DEBUG: result = ".$db->ErrorMsg()."<br/>&nbsp;&nbsp;".$db->sql."<br/>"; die();
     }
-  else if ($name == '')
-    {
-      echo $this->ShowErrors($this->Lang('nonamegiven'));
-    }
-  else if( !$this->is_alias($name) )
-    {
-      echo $this->ShowErrors($this->Lang('error_invalid_name'));
-    }
-  else if( !empty($max_length) && !is_numeric($max_length) )
-    {
-      echo $this->ShowErrors($this->Lang('notanumber'));
-    }
-  else if( $type == 'subscription' && $db->GetOne('SELECT id FROM '.cms_db_prefix().'module_products_fielddefs WHERE type = ?',array($type)) )
-    {
-      echo $this->ShowErrors($this->Lang('error_onesubscriptionfield'));
-    }
-  else if( $type == 'quantity' && $db->GetOne('SELECT id FROM '.cms_db_prefix().'module_products_fielddefs WHERE type = ?',array($type)) )
-    {
-      echo $this->ShowErrors($this->Lang('error_onequantityfield'));
-    }
-  else
-    {
-      $max = $db->GetOne('SELECT max(item_order) + 1 FROM ' . cms_db_prefix() . 'module_products_fielddefs');
-      if( !$max ) $max = 0;
-      $query = 'INSERT INTO '.cms_db_prefix().'module_products_fielddefs (name, prompt, type, max_length, item_order, create_date, modified_date, public, options) VALUES (?,?,?,?,?,?,?,?,?)';
-      $parms = array($name, $prompt, $type, $max_length, $max, 
-		     trim($db->DBTimeStamp(time()), "'"), 
-		     trim($db->DBTimeStamp(time()), "'"),
-		     $public,$options);
-      $dbr = $db->Execute($query, $parms );
-      if( !$dbr ) {
-	echo "DEBUG: result = ".$db->ErrorMsg()."<br/>&nbsp;&nbsp;".$db->sql."<br/>"; die();
-      }
       
-      $this->RedirectToTab($id);
-    }
+    $this->RedirectToTab($id);
+  }
 }
 
 #Display template
 $smarty->assign('options',$options);
-$smarty->assign('startform', 
-		$this->CGCreateFormStart($id, 'addfielddef', $returnid));
+$smarty->assign('startform', $this->CGCreateFormStart($id, 'addfielddef', $returnid));
 $smarty->assign('endform', $this->CreateFormEnd());
 $smarty->assign('inputname', $this->CreateInputText($id, 'name', $name, 30, 255));
 $smarty->assign('inputprompt',$this->CreateInputText($id,'prompt',$prompt,50,255));
@@ -145,14 +98,10 @@ $addtext = "onChange='this.form.submit()'";
 $smarty->assign('inputtype', $this->GetTypesDropdown($id, 'type', $type, $addtext, true));
 $smarty->assign('type',$type);
 
-if( $type == 'textbox' )
-  {
-    $smarty->assign('inputmaxlength', $this->CreateInputText($id, 'max_length', $max_length, 30, 255));
-  }
+if( $type == 'textbox' ) $smarty->assign('inputmaxlength', $this->CreateInputText($id, 'max_length', $max_length, 30, 255));
 
 $smarty->assign('userviewtext',$this->Lang('public'));
-$smarty->assign('input_userview',
-		$this->CreateInputcheckbox($id, 'public', 1, $public));
+$smarty->assign('input_userview', $this->CreateInputcheckbox($id, 'public', 1, $public));
 
 $smarty->assign('hidden', '');
 $smarty->assign('submit', $this->CreateInputSubmit($id, 'submit', lang('submit')));
