@@ -40,40 +40,44 @@ if( !isset($gCms) ) exit;
 if( !$this->CheckPermission('Modify Products') ) exit;
 
 $this->SetCurrentTab('products');
-if( isset($params['multiselect']) && is_array($params['multiselect']) && count($params['multiselect']) && isset($params['bulkaction']) )
-  {
-    for( $i = 0; $i < count($params['multiselect']); $i++ )
-      {
-	$params['multiselect'][$i] = (int)$params['multiselect'][$i];
-      }
-
-    switch( $params['bulkaction'] )
-      {
-      case 'delete':
-	foreach( $params['multiselect'] as $productid )
-	  {
-	    $res = $this->DeleteProduct((int)$productid);
-	  }
-	break;
-      case 'setdraft':
-	{
-	  $now = $db->DbTimeStamp(time());
-	  $query = 'UPDATE '.cms_db_prefix()."module_products SET status = ?, modified_date = $now WHERE id IN (";
-	  $query .= implode(',',$params['multiselect']).')';
-	  $dbr = $db->Execute($query,array('draft'));
-	}
-	break;
-      case 'setpublished':
-	{
-	  $now = $db->DbTimeStamp(time());
-	  $query = 'UPDATE '.cms_db_prefix()."module_products SET status = ?, modified_date = $now WHERE id IN (";
-	  $query .= implode(',',$params['multiselect']).')';
-	  $dbr = $db->Execute($query,array('published'));
-	}
-	break;
-      }
+if( isset($params['multiselect']) && is_array($params['multiselect']) && count($params['multiselect']) && isset($params['bulkaction']) ) {
+  for( $i = 0; $i < count($params['multiselect']); $i++ ) {
+    $params['multiselect'][$i] = (int)$params['multiselect'][$i];
   }
 
+  switch( $params['bulkaction'] ) {
+  case 'delete':
+    foreach( $params['multiselect'] as $productid ) {
+      $res = $this->DeleteProduct((int)$productid);
+    }
+    break;
+  case 'setdraft':
+    {
+      $now = $db->DbTimeStamp(time());
+      $query = 'UPDATE '.cms_db_prefix()."module_products SET status = ?, modified_date = $now WHERE id IN (";
+      $query .= implode(',',$params['multiselect']).')';
+      $dbr = $db->Execute($query,array('draft'));
+    }
+    break;
+  case 'setdisabled':
+    {
+      $now = $db->DbTimeStamp(time());
+      $query = 'UPDATE '.cms_db_prefix()."module_products SET status = ?, modified_date = $now WHERE id IN (";
+      $query .= implode(',',$params['multiselect']).')';
+      $dbr = $db->Execute($query,array('disabled'));
+    }
+    break;
+  case 'setpublished':
+    {
+      $now = $db->DbTimeStamp(time());
+      $query = 'UPDATE '.cms_db_prefix()."module_products SET status = ?, modified_date = $now WHERE id IN (";
+      $query .= implode(',',$params['multiselect']).')';
+      $dbr = $db->Execute($query,array('published'));
+    }
+    break;
+  }
+}
+
 $this->Setmessage($this->Lang('operation_complete'));
 $this->RedirectToTab($id);
 #
