@@ -66,10 +66,7 @@ if( isset($params['copyattribs']) ) {
 if( isset($params['submit']) ) {
   try {
 	$attribs = products_attrib::load_from_form($params);
-
-	if( !is_array($attribs) && count($attribs) ) {
-	  throw new CmsException('No product options to save');
-	}
+	if( !is_array($attribs) && count($attribs) ) throw new CmsException('No product options to save');
 
 	products_attrib::delete_by_product($params['prodid']);
 	foreach( $attribs as $attrib ) {
