@@ -214,14 +214,12 @@ if (isset($params['submit'])) {
 	  case 'file':
 	    if( isset($def->value)) {
 	      $str = "field-$fid";
-	      if( isset($_FILES[$id.'customfield']['name'][$str]) &&
-		  isset($_FILES[$id.'customfield']['size'][$str]) &&
+	      if( isset($_FILES[$id.'customfield']['name'][$str]) && isset($_FILES[$id.'customfield']['size'][$str]) &&
 		  $_FILES[$id.'customfield']['size'][$str] > 0 ) {
 		products_delete_uploaded_file($destdir,$def->value);
 	      }
 	    }
-	    $destdir = cms_join_path($gCms->config['uploads_path'],$this->GetName(),
-				     'product_'.$compid);
+	    $destdir = cms_join_path($gCms->config['uploads_path'],$this->GetName(),'product_'.$compid);
 	    cge_dir::mkdirr($destdir);
 	    if( !is_dir($destdir) ) die('directory still does not exist');
 	    $handler = new cg_fileupload($id,$destdir);
@@ -229,8 +227,7 @@ if (isset($params['submit'])) {
 	    $res = $handler->handle_upload('customfield','','field-'.$fid);
 	    $err = $handler->get_error();
 	    if( !$res && $err != cg_fileupload::NOFILE ) {
-	      $errors[] = sprintf("%s %s: %s",$this->Lang('field'),$def->name,
-				  $this->GetUploadErrorMessage($err));
+	      $errors[] = sprintf("%s %s: %s",$this->Lang('field'),$def->name, $this->GetUploadErrorMessage($err));
 	    }
 	    else if( !$res && !empty($v) ) {
 	      true;
@@ -246,19 +243,16 @@ if (isset($params['submit'])) {
 	  case 'image':
 	    if( isset($def->value) ) {
 	      $str = "field-$fid";
-	      if( isset($_FILES[$id.'customfield']['name'][$str]) &&
-		  isset($_FILES[$id.'customfield']['size'][$str]) &&
+	      if( isset($_FILES[$id.'customfield']['name'][$str]) && isset($_FILES[$id.'customfield']['size'][$str]) &&
 		  $_FILES[$id.'customfield']['size'][$str] > 0 ) {
 		products_delete_uploaded_file($destdir,$def->value);
 	      }
 	    }
 	    $attr = 'default'; // use default value for wmlocation
-	    if( isset($_REQUEST[$id.'customfield_attr']) && 
-		isset($_REQUEST[$id.'customfield_attr'][$k]) ) {
+	    if( isset($_REQUEST[$id.'customfield_attr']) && isset($_REQUEST[$id.'customfield_attr'][$k]) ) {
 	      $attr = $_REQUEST[$id.'customfield_attr'][$k];
 	    }
-	    $destdir = cms_join_path($gCms->config['uploads_path'],$this->GetName(),
-				     'product_'.$compid);
+	    $destdir = cms_join_path($gCms->config['uploads_path'],$this->GetName(),'product_'.$compid);
 	    $res = $this->HandleUploadedImage($id,'customfield',$destdir,$errors,'field-'.$fid,$attr);
 	    if( $res === FALSE ) {
 	      $v = null;
@@ -287,6 +281,11 @@ if (isset($params['submit'])) {
 	  case 'dropdown':
 	    break;
 
+	  case 'companydir':
+	    $v = (int)$v;
+	    if( $v < 1 ) $v = null;
+	    break;
+
 	  default:
 	    die("unknown type: ".$def->type);
 	    break;
@@ -315,15 +314,13 @@ if (isset($params['submit'])) {
     if ($module != FALSE) {
       $module->DeleteWords($this->GetName(), $compid, 'product');
       if( $status == 'published' ) {
-	$module->AddWords($this->GetName(), $compid, 'product', 
-			  implode(' ', $this->GetSearchableText($compid) ) );
+	$module->AddWords($this->GetName(), $compid, 'product', implode(' ', $this->GetSearchableText($compid) ) );
       }
     }
 
     if( count($errors) ) {
       echo $this->ShowErrors($errors);
       echo $this->ShowErrors($this->Lang('info_fieldproblems'));
-      return;
     }
     else {
       $this->RedirectToTab($id);
@@ -475,6 +472,15 @@ if (count($fielddefs) > 0) {
       $field->input_box = $this->CreateInputText($id, 'customfield[field-'.$fielddef->id.']', $value, 4, 4);
       break;
 
+    case 'companydir':
+      $cdmod = cms_utils::get_module('CompanyDirectory','1.19');
+      if( $cdmod ) {
+	$field->input_box = $this->CreateInputText($id,'customfield[field-'.$fielddef->id.']',$value,10,10,
+						   "placeholder=\"{$this->Lang('cd_autocomplete')}\" title=\"{$this->Lang('title_cdautocomplete')}\"");
+	$field->input_box = '<span class="cdautocomplete">'.$field->input_box.'</span>';
+      }
+      break;
+
     case 'textbox':
     default:
       $field->input_box = $this->CreateInputText($id, 'customfield[field-'.$fielddef->id.']', $value, 30, 255);
@@ -522,13 +528,11 @@ if( count($catarray) > 0 ) {
   $n = count($catarray)/4;
   $n = min($n,20);
   $n = max($n,5);
-  $smarty->assign('input_categories',
-		  $this->CreateInputSelectList($id,'categories[]',$catarray,$selcatarray,$n));;
- }
+  $smarty->assign('input_categories', $this->CreateInputSelectList($id,'categories[]',$catarray,$selcatarray,$n));;
+}
 
 $smarty->assign('taxabletext',$this->Lang('taxable'));
-$smarty->assign('inputtaxable',
-		$this->CreateInputCheckbox($id,'taxable',1,$taxable));
+$smarty->assign('inputtaxable',	$this->CreateInputCheckbox($id,'taxable',1,$taxable));
 
 $hierarchy_items = $this->BuildHierarchyList();
 $smarty->assign('hierarchy_items',$hierarchy_items);
@@ -538,9 +542,7 @@ $statuses = array($this->Lang('published')=>'published',
 		  $this->Lang('draft')=>'draft',
 		  $this->Lang('disabled')=>'disabled');
 $smarty->assign('statustext',$this->Lang('status'));
-$smarty->assign('inputstatus',
-		$this->CreateInputDropdown($id,'status',
-					   $statuses,-1,$status));
+$smarty->assign('inputstatus', $this->CreateInputDropdown($id,'status',$statuses,-1,$status));
 
 $smarty->assign('idtext',$this->Lang('id'));
 $smarty->assign('compid',$compid);
