@@ -40,7 +40,7 @@ if( !isset($gCms) ) exit;
 
 $fields = '';
 {
-  $tmp = $this->GetFieldDefs();
+  $tmp = product_utils::get_fielddefs();
   if( is_array($tmp) )
     {
       for( $i = 0; $i < count($tmp); $i++ )
