@@ -44,7 +44,7 @@ if( cge_tmpdata::exists(__FILE__) ) return;
 cge_tmpdata::set(__FILE__,1);
 
 // get the field definitions.
-$defs = $this->GetFieldDefs(TRUE<TRUE);
+$defs = product_utils::get_fielddefs(TRUE<TRUE);
 
 // check field defs for an entry of type 'quantity'
 if( !is_array($defs) || count($defs) == 0 ) return;
