@@ -38,18 +38,24 @@
 
 function products_SearchReindex(&$mod,$module)
 {
-  $db = $mod->GetDb();
-  
-  $query = 'SELECT id FROM '.cms_db_prefix().'module_products where status = ?';
-  $result = &$db->Execute($query,array('published'));
-  
-  while ($result && !$result->EOF)
-    {
-      $data = $mod->GetSearchableText($result->fields['id']);
-      $module->AddWords($mod->GetName(), $result->fields['id'], 'product', 
-			implode(' ', $data ) );
-      $result->MoveNext();
-    }
+  $page = 1;
+  $done = FALSE;
+  while( !$done ) {
+	$parms = array('status'=>'published','limit'=>250,'page'=>$page);
+	$query = new products_query($parms);
+	$rs = $query->execute();
+	while( !$rs->EOF() ) {
+	  $tmp = $rs->get_product(FALSE,TRUE);
+	  $words = $mod->GetSearchableText($tmp);
+	  if( is_array($words) && count($words) ) $module->AddWords($mod->GetName(),$tmp['id'],'product',implode(' ',$words));
+	  $rs->MoveNext();
+	}
+	if( $page == $rs->numpages ) {
+	  $done = TRUE;
+	  break;
+	}
+	$page++;
+  }
 }
 
 function products_BuildHierarchyList(&$mod)
