@@ -46,10 +46,13 @@ $lang['categoryexists'] = 'A category by that name already exists';
 $lang['categorylisttemplates'] = 'CategoryList Templates';
 $lang['categorylisttemplate_addedit'] = 'Add/Edit A CategoryList Template';
 $lang['centimeters'] = 'Centimeters';
+$lang['cd_autocomplete'] = 'Type the start of a company name';
 $lang['checkbox'] = 'Checkbox';
+$lang['companydir_reference'] = 'CompanyDirectory Company Id';
 $lang['confirm_copyoptions'] = 'Any existing options for this item will be replaced. Are you sure you want to continue?';
 $lang['confirm_delete_hierarchy_node'] = 'Are you sure you want to delete this node?  Any items that are using this node will be set to no hierarchy';
 $lang['confirm_deletealloptions'] = 'Are you sure you want to delete all options for this product?';
+$lang['confirm_editoptions'] = 'Are you sure you want to abandon this form and edit the options for this product?';
 $lang['confirm_import'] = "Are you sure you really want to do this?\\n\\nImproper settings, or an invalid config file could completely corrupt a currently valid and working system.";
 $lang['copy'] = 'Copy';
 $lang['copy_product'] = 'Copy this item';
@@ -63,13 +66,13 @@ $lang['current_value'] = 'Current Value';
 # D
 $lang['data'] = 'Data';
 $lang['default'] = 'Default';
-$lang['defaulttemplates'] = 'Default Templates';
+$lang['defaulttemplates'] = 'Prototype Templates';
 $lang['default_template_notice'] = <<<EOT
-<strong>Note:</strong> The contents of these text areas are used to determine the default content of templates when you click &quot;Add Template&quot; in the appropriate template tab.  Editing one of these text areas will have no immediate effect on your website.
+<strong>Note:</strong> prototype templates are used to determine the default content of templates when you click &quot;Add Template&quot; in the appropriate template tab.  Editing one of these text areas will have no immediate effect on your website.
 EOT;
 $lang['delete'] = 'Delete';
 $lang['delete_all'] = 'Delete All';
-$lang['delete_attribset'] = 'Delete Attribute';
+$lang['delete_attribute'] = 'Delete Attribute';
 $lang['delete_hierarchy_item'] = 'Delete Hierarchy Item';
 $lang['descending'] = 'Descending';
 $lang['description'] = 'Description';
@@ -100,11 +103,13 @@ $lang['edit_product'] = 'Edit Item ';
 $lang['errors'] = 'Errors';
 $lang['error_attribset_exists'] = 'An attribute with that name already exists';
 $lang['error_dberror'] = 'Database error';
+$lang['error_delete_lastrow'] = 'The last row cannot be deleted this way';
 $lang['error_duplicate_sku'] = 'Duplicate SKU value found';
 $lang['error_fieldvalue_empty'] = 'The field value cannot be empty';
 $lang['error_fileformat'] = 'File Format Problem';
 $lang['error_filenotfound'] = 'File Not Found';
 $lang['error_fileopen'] = 'Problem opening file %s';
+$lang['error_invalidcdvalue'] = 'Invalid CompanyDirectory company id specified';
 $lang['error_invalidparamcount'] = 'Invalid (or not matching) parameter count';
 $lang['error_invalidparent'] = 'Invalid Parent (a hierarchy node cannot be it\'s own parent)';
 $lang['error_invalid_name'] = 'The custom field value entered is invalid (contains non alphanumeric characters)';
@@ -183,9 +188,12 @@ $lang['info_createcategories'] = 'Automatically create item categories to match
 $lang['info_createhierarchy'] = 'Automatically create item hierarchies to match those of the CSV file if it does not already exist';
 $lang['info_decimal_units'] = 'This system understands (.) as the decimal point separator. i.e.: <strong>5.25</strong>';
 $lang['info_delimiter'] = 'Specify the character (or characters) that seperate each field';
+$lang['info_dropdown_options'] = 'Separate values from labels for options by separating them with a pipe | character.  i.e: f|Female.  One option per line.';
 $lang['info_duplicateproducts'] = 'Specify how the system should handle an item whos name already exists in the CSV file';
 $lang['info_fielddefs_tab'] = '<strong>Note: </strong> All Fields defined here are available to all items.';
 $lang['info_fieldproblems'] = 'Problems were encountered when dealing with one or more custom fields.  The action has completed successfully, however you should investigate and correct these problems';
+$lang['info_filter_productname'] = 'Enter a product name substring.  Wildcard characters are % and *';
+$lang['info_filter_sku'] = 'Enter a sku substring.  Wildcard characters are % and *.  If the product name field is not empty, this field will be ignored.';
 $lang['info_handleimages'] = 'Upon import, if an image filename is found in a field column, should it be moved from the source location, watermarked, thumbnailed, and the field type changed to &quot;image&quot;';
 $lang['info_hierpage'] = 'Use this page for hierarchy views.  The pageid will not be spefiried on the URL.';
 $lang['info_imagepath'] = 'The path (relative to the uploads directory) where images referred to in the import file, can be found';
@@ -215,6 +223,7 @@ $lang['modifieddate'] = 'Modified Date';
 $lang['module_description'] = 'A module for managing a catalog of items, their price, images, etc, and for allowing users to build a cart';
 $lang['move_down'] = 'Move Down';
 $lang['move_up'] = 'Move Up';
+$lang['msg_category_deleted'] = 'Category Deleted';
 $lang['msg_eventhandlers_created'] = 'Event handlers created';
 $lang['msg_optionscopied'] = 'Product options copied (but not saved yet)';
 $lang['msg_options_deleted'] = 'Product options deleted for product %d';
@@ -232,6 +241,7 @@ $lang['nonamegiven'] = 'No name was supplied';
 $lang['none'] = 'None';
 $lang['notes'] = 'Notes';
 $lang['nothing_selectd'] = 'Nothing selected';
+$lang['numeric'] = 'Numeric';
 
 # O
 $lang['of'] = 'Of';
@@ -264,7 +274,7 @@ $lang['param_categoryfield'] = 'Applicable only to the &quot;categorylist&quot;
 $lang['param_categorylisttemplate'] = 'Useful only with the categorylist and fieldlist actions, this parameter indicates the template that should be used for the display.  If no value is specified then the current default template of that type is used.';
 $lang['param_categorylistdtltemplate'] = 'Useful only with the categorylist actions, this parameter indicates the template that should be used for the display of the category details.  This uses a category list template..  If no value is specified then the current default template of that type is used.';
 $lang['param_detailpage'] = 'This specifies the pageid or alias that should be used to display the detail report.  It can be used with the <em>default</em> or search actions.  This option is not compatible with pretty urls of any sort.';
-$lang['param_detailtemplate'] = 'This parameter specifies the template that should be used for the detail mode display.  If no value is specified, then the current default template of that type is used.  This parameter has no use when pretty urls are enabled.';
+$lang['param_detailtemplate'] = 'This parameter specifies the template that should be used for the detail mode display.  If no value is specified, then the current default template of that type is used.  This parameter has no effect when pretty urls are enabled.';
 $lang['param_excludecat'] = 'Applicable only to the default (summary) view, this parameter will allow excluding items that are in a specific category from the result. A comma separated list of category names is allowed. This parameter can work in conjunction with the category parameter to provide a list of the items that are in this category, but not in that category';
 $lang['param_field'] = 'Used in the <em>fieldlist</em> and the <em>ajax_propval</em> actions. In the fieldlist action, this parameter is required to specify the name of a user defined property to create a list from.  In the ajax_propval action this parameter is used to specify which field to use to extract a list of values.  Any valid field names are accepted (though only text field and dropdown field names will work properly.  Additionally the special values ::name::, ::sku::, and ::alias:: can be specified to return values from the item name, sku and alias respectively.';
 $lang['param_fieldval'] = 'Used in the <em>default</em> and <em>ajax_propval</em> actions, this parameter allows specifying a field value to limit results by.  In the default value these special values are accepted: &quot;::null::&quot; &quot;::notnull::&quot; and wildcard chars (* or %). In the ajax_propval action this field is expected to contain only a few letters, to indicate a small filter.  i.e: fieldval=b to return all field values that begin with the letter b.';
@@ -277,8 +287,8 @@ $lang['param_parent'] = 'Useful only in the <em>hierarchy</em> action, this para
 $lang['param_parents'] = 'Useful only in the <em>hierarchy</em> action, this parameter specifies a comma separated list of hierarchy names that specify to create numerous heirarchy trees from the specified location(s).  Hierarchy names must be unique, and not contain any special chars.';
 $lang['param_productid'] = 'Useful only with the detail action, this parameter indicates what item to use for the display.';
 $lang['param_productlist'] = 'Applicable only to the default (summary) view, this parameter allows specifying a comma separated list of integer product ids to display.  No pagination or sorting is performed on these values, and if specified the other filtering parameters to the summary view are ignored.';
-$lang['param_resultpage'] = 'Applicable only to the search, and category list actions, this parameter specifies a page id or alias to use to display the summary results';
-$lang['param_searchfield'] = 'Applicable only to the search action, this parameter may contain a comma separated list of field names to include in the search';
+$lang['param_resultpage'] = 'Applicable only to the search, and category list actions, this parameter specifies a page id or alias to use to display the summary results.  If specified, this will override the inline parameter.';
+$lang['param_searchfield'] = '<em>(deprecated)</em> Applicable only to the search action, this parameter may contain a comma separated list of field names to include in the search';
 $lang['param_searchformtemplate'] = 'Applicable only to the search action, thisparameter allows specifying a non default search form template';
 $lang['param_showall'] = 'Applicable only to the categorylist and fieldlist actions, if this parameter is set to a non 0 integer value all categories (even those without items) will be displayed.';
 $lang['param_sortorder'] = 'Specify the order of sorted fields in summary (including after a search) view.  Possible values are:
@@ -339,7 +349,7 @@ $lang['prompt_applicable'] = 'Enable by default for all new items';
 $lang['prompt_batchsize'] = 'Batch Size';
 $lang['prompt_cart_module'] = 'Cart Module';
 $lang['prompt_cart_module_params'] = 'Cart Module Parameters';
-$lang['prompt_clearattribs'] = 'Clear attributes on update';
+$lang['prompt_clearattribs'] = 'Clear Options on update';
 $lang['prompt_clearcategories'] = 'Clear categories on update';
 $lang['prompt_clearfields'] = 'Clear fields on update';
 $lang['prompt_createcategories'] = 'Create Categories';
@@ -404,8 +414,9 @@ $lang['searchtemplate_addedit'] = 'Add/Edit Search Form Template';
 $lang['searchtemplates'] = 'Search Templates';
 $lang['select_all'] = 'Select All';
 $lang['select_one'] = 'Select One';
-$lang['setdraft'] = 'Set As Draft';
-$lang['setpublished'] = 'Set As Published';
+$lang['setdisabled'] = 'Set as Disabled';
+$lang['setdraft'] = 'Set as Draft';
+$lang['setpublished'] = 'Set as Published';
 $lang['sku'] = 'SKU';
 $lang['sort_by'] = 'Sort By';
 $lang['sort_order'] = 'Sort Order';
@@ -433,13 +444,14 @@ $lang['textarea'] = 'Text Area';
 $lang['textbox'] = 'Text Input';
 $lang['title_adjustment'] = 'Enter an adjustment from the base price for the product options.  Syntax is [+-]#.##';
 $lang['title_attribute_text'] = 'Enter a brief description for this product option';
-$lang['title_byhierarchy_dflttemplate'] = 'Default New Hierarchy Report Template';
-$lang['title_categorylist_dflttemplate'] = 'Default New CategoryList Template';
-$lang['title_detail_dflttemplate'] = 'Default New Detail Template';
+$lang['title_byhierarchy_dflttemplate'] = 'Prototype Hierarchy Report Template';
+$lang['title_categorylist_dflttemplate'] = 'Prototype CategoryList Template';
+$lang['title_cdautocomplete'] = 'This field expects an integer company ID.  It is an autocomplete field. Enter the first few characters of a company name and select the desired entry from the matching items.  The more characters entered the fewer results returned.';
+$lang['title_detail_dflttemplate'] = 'Prototype Detail Template';
 $lang['title_qoh'] = 'Optionally specify a quantity on hand for this product option.  Note for quantity adjustments to be automatic the SKU field must also be populated';
-$lang['title_search_dflttemplate'] = 'Default New Search Template';
+$lang['title_search_dflttemplate'] = 'Prototype Search Template';
 $lang['title_sku'] = 'The SKU is used for managing quantity on hand, and promotions for product options.';
-$lang['title_summary_dflttemplate'] = 'Default New Summary Template';
+$lang['title_summary_dflttemplate'] = 'Prototype Summary Template';
 $lang['type'] = 'Type';
 
 # U
