@@ -114,75 +114,6 @@ $lang['filters'] = 'Filtres';
 $lang['firstpage'] = '&amp;lt;&amp;lt;';
 $lang['general_settings'] = 'Param&egrave;tres g&eacute;n&eacute;raux';
 $lang['go'] = 'Envoyer';
-$lang['help'] = '<h3>Que fait ce module ?</h3>
-<p>Ce module permet de d&eacute;finir, d&#039;organiser et d&#039;afficher les donn&eacute;es de produits et des cat&eacute;gories associ&eacute;es. Il peut s&#039;int&eacute;grer dans une solution de commerce &eacute;lectronique, mais aussi fonctionner de mani&egrave;re autonome. Les produits peuvent appartenir &agrave; une ou plusieurs cat&eacute;gories. Le prix et le poids des produits est g&eacute;r&eacute; par le module, et des informations suppl&eacute;mentaires (attributs) peuvent &ecirc;tre ajout&eacute;es. Chaque attribut peut d&eacute;finir une modification du prix du produit.  Un indicateur permet de d&eacute;finir si par d&eacute;faut un produit est ou non tax&eacute;.</p>
-  <p>Le module permet d&#039;attacher jusqu&#039;&agrave; deux images &agrave; un produit, de d&eacute;finir des champs personnalis&eacute;s publics ou priv&eacute;s.</p>
-<h3>Fonctions :</h3>
-<ul>
-  <li>Types d&#039;affichage</li>
-    <ul>
-      <li>Affichage r&eacute;sum&eacute;</li>
-      <li>Affichage par cat&eacute;gorie</li>
-      <li>Affichage d&eacute;taill&eacute;</li> 
-      <li>Affichage hi&eacute;rarchique</li>
-    </ul>
-  <li>Tous les gabarits sont stock&eacute;s dans la base de donn&eacute;es</li>
-  <p>Pour chaque type d&#039;affichage plusieurs gabarits peut &ecirc;tre cr&eacute;&eacute;s, avec un gabarit par d&eacute;faut, et des gabarits pass&eacute;s en param&egrave;tre de chacun des type d&#039;affichage.</p>
-  <li>Tri et affichage page par page dans dans l&#039;affichage r&eacute;sum&eacute;</li>
-  <li>Les produits peuvent figurer dans plusieurs cat&eacute;gories</li>
-  <li>Possibilit&eacute; de d&eacute;finir autant d&#039;attributs personnalis&eacute;s que n&eacute;cessaire, y compris de type image ou fichier.</li>
-  <li>Cr&eacute;ation automatique des images miniatures</li>
-  <li>Attributs d&eacute;finis par l&#039;administrateur</li>
-  <li>Attributs de produits (avec possibilit&eacute; d&#039;ajustement du prix)</li>
-  <li>Poids et indicateur de taxation (pour l&#039;int&eacute;gration &agrave; un syst&egrave;me de commerce &eacute;lectronique)</li>
-  <li>Les produits ont un statut de publication (brouillon/publi&eacute;), qui permet de les masquer dans la partie publique si besoin est.</li>
-  <li>Support des URL simples</li>
-  <li><strong>Et bien plus encore...</strong></li>
-</ul>
-
-<h3>Comment l&#039;utiliser ?</h3>
-<ul>
-<li>D&eacute;finir les pr&eacute;f&eacute;rences</li>
-<p>Ce n&#039;est en principe qu&#039;une formalit&eacute;. Vous devez indiquer l&#039;unit&eacute; de poids et le code mon&eacute;taire que vous souhaitez utiliser.</p>
-
-<li>Configurer les utilisateurs du catalogue et leurs permissions</li>
-<p>Ce module utilise la permission &#039;Modifier les gabarits&#039; (ModifyTemplates) pour attribuer l&#039;autorisation de modifier les divers gabarits du module.  De m&ecirc;me, la permission &#039;Modifier les pr&eacute;f&eacute;rences du site&#039; (Modify Site Preferences) est n&eacute;cessaire pour modifier les pr&eacute;f&eacute;rences du module. Pour pouvoir modifier la d&eacute;finition des attributs, les cat&eacute;gories ou les produits, les utilisateurs doivent avoir la permission &#039;Modifier les Produits&#039; (Modify Products).</p>
-
-<li>Cr&eacute;er des cat&eacute;gories (optionnel)</li>
-<p>Cette &eacute;tape n&#039;est pas indispensable, mais vous devriez d&eacute;finir des cat&eacute;gories maintenant pour &eacute;viter plus tard d&#039;avoir &agrave; revenir modifier chaque produit si vous changez d&#039;avis. Pour ajouter une cat&eacute;gorie, cliquer sur l&#039;onglet &#039;Cat&eacute;gories&#039; du Gestionnaire de Produits, puis sur &#039;Ajouter une cat&eacute;gorie&#039;. Vous devrez ensuite indiquer le nom de cette nouvelle cat&eacute;gorie.</p>
-
-<li>Cr&eacute;er des attributs (optionnel)</li>
-<p>Cette &eacute;tape n&#039;est pas indispensable si le module r&eacute;pond exactement &agrave; votre besoin. Par contre, si vous souhaitez d&eacute;finir des informations suppl&eacute;mentaires pour chaque produit, vous devez cr&eacute;er ces attributs.  La cr&eacute;ation d&#039;attributs ressemble &agrave; la cr&eacute;ation de cat&eacute;gories, mais vous devez indiquer un peu plus d&#039;informations.</p>
-<p>Actuellement, six type d&#039;attributs sont disponibles: &#039;textbox&#039; (champ de texte),&#039;checkbox&#039; (case &agrave; cocher), &#039;textarea&#039; (zone de texte), dropdown (menu d&eacute;roulant), &#039;image&#039; (fichier image) et &#039;file&#039; (fichier quelconque).  Choisissez un type d&#039;attribut, donnez-lui un nom, un label d&#039;affichage, et indiquez si cet attribut est visible ou non dans la partie publique.</p>
-
-<li>Cr&eacute;er des produits</li>
-<p>Vous devez cr&eacute;er des produits pour que ce module puisse afficher quelque chose dans la partie publique du site. Pour chacun des produits, indiquez un nom, un prix (optionnel) un poids (optionnel), un statut (publi&eacute;/brouillon), et &eacute;ventuellement d&#039;autres informations. Vous pouvez aussi indiquer si le produit est soumis aux taxes.</p>
-<p>Si vous avez cr&eacute;&eacute; des cat&eacute;gories, la liste de ces cat&eacute;gorie est affich&eacute;es, et vous pouvez en s&eacute;lectionner la ou les cat&eacute;gories auxquelles ce produit appartient.</p>
-<p>Si des attributs ont &eacute;t&eacute; d&eacute;finis, les champs de saisie associ&eacute;s sont affich&eacute;s, et vous pourrez saisir les valeurs de chaque attribut. La saisie des attributs est optionnelle.</p>
-
-<li>Ajoutez les balises du module dans vos gabarits et/ou dans vos pages</li>
-
-<p>Il suffit d&#039;ins&eacute;rer la balise <strong>{Products}</strong> dans le contenu d&#039;une de vos pages, ou dans un de vos gabarits.</p>
-<p>Pour utiliser d&#039;autres fonctions, vous devez ajouter un ou plusieurs param&egrave;tres &agrave; la balise <strong>{Products}</strong>. La liste de ces param&egrave;tres figure un peu plus bas. Par exemple, pour afficher la liste des produits appartenant &agrave; une cat&eacute;gorie, utilisez une balise comme <code>{Products category=&#039;nom_de_la_categorie&#039;}</code></p>
-</ul>
-
-<h3>Plugins Smarty</h3>
-<p>Ce module d&eacute;finit un ou plusieurs plugins Smarty afin de vous permettre de r&eacute;cup&eacute;rer diff&eacute;rentes informations sur les produits &agrave; inclure dans les gabarits de produits :</p>
-<ul>
-  <li>{products_getcategory categoryid=&#039;99&#039; [assign=&#039;tmp&#039;]}
-  <p>Ce plugin permet la r&eacute;cup&eacute;ration de toutes les informations d&#039;une cat&eacute;gorie sp&eacute;cifique (s&eacute;lection par champ ID). Il peut de mani&egrave;re optionnelle assigner ces informations &agrave; une variable smarty (dans l&#039;exemple : <em>tmp</em>). Cette variable devient alors un objet contenant toutes les informations de la cat&eacute;gorie, y compris les valeurs des champs.<br/>Par exemple : <code>
-{products_getcategory categoryid=1 assign=&#039;tmp&#039;}Nom de la cat&eacute;gorie = {$tmp->name}</code></p>
-  </li>
-</ul>
-
-<h3>Assistance</h3>
-<p>Ce module est fourni sans aucune assistance commerciale. Cependant, vous pouvez tout de m&ecirc;me obtenir de l&#039;aide:</p>
-<ul>
-<li>Pour obtenir la derni&egrave;re version de ce module, consulter la FAQ, ou signaler un bug, rendez-vous sur la <a href="http://dev.cmsmadesimple.org">Developers Forge</a> de CMS Made Simple, et faites une recherche de &#039;Products&#039;.</li>
-<li>Pour obtenir une assistance commerciale, contactez par mail <a href="mailto:calguy1000@cmsmadesimple.org">Robert Campbell</a>, l&#039;auteur de ce module.</li>
-<li>Les <a href="http://forum.cmsmadesimple.org">Forums CMS Made Simple</a> sont aussi une pr&eacute;ciseuse source d&#039;informations.</li>
-<li>Pour des questions simples est un support technique de base, vous pouvez contacter l&#039;auteur du module sur <a href="irc://irc.freenode.net/#cms">le channel IRC CMS</a>.</li>
-</ul>';
 $lang['hierarchy'] = 'Hierarchie';
 $lang['hierarchy_position'] = 'Position dans la hi&eacute;rarchie';
 $lang['hierarchy_settings'] = 'Param&egrave;tres de hi&eacute;rarchie';
@@ -437,4 +368,4 @@ $lang['utma'] = '156861353.206568057.1317628053.1317628053.1317628053.1';
 $lang['utmc'] = '156861353';
 $lang['utmz'] = '156861353.1317628053.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmb'] = '156861353';
-?>
\ No newline at end of file
+?>
