@@ -108,57 +108,6 @@ $lang['filters'] = 'Filtri';
 $lang['firstpage'] = '<<';
 $lang['general_settings'] = 'Configurazioni generali';
 $lang['go'] = 'Vai';
-$lang['help'] = '<h3>What does this do?</h3>
-<p>This module provides a way to collect, organize, and display information about products and their categories.  This module can stand on its own, or be part of an e-commerce solution if you wish.  The module supports a product existing in more than one category, supports product weight, price, and attribute sets.  Each item in an attribute set can have a price adjustment.  Also a global flag indicates wether the product is &#039;taxable&#039; or not.</p>
-  <p>This module provides for up to two images per product, custom field definitions, and for the ability to descriminate private from public data.</p>
-<h3>Features:</h3>
-<ul>
-  <li>Numerous Views</li>
-    <ul>
-      <li>Summary view</li>
-      <li>Detail view</li> 
-      <li>Category List View</li>
-    </ul>
-  <li>Entirely Database Template Driven</li>
-  <p>Numerous templates of each type can be defined, defaults specified for each type, and the template used for each particular view can be specified as a parameter</p>
-  <li>Sorting and pagination in the summary view</li>
-  <li>Products can exist in multiple categories</li>
-  <li>Up to two images per product</li>
-  <li>Admin defined fields</li>
-  <li>Product attributes (including price adjustment)</li>
-  <li>Weight and taxable fields (for use in e-commerce solutions)</li>
-  <li>Products can have a status (published or draft) in order to hide products from public display at any time</li>
-  <li>Pretty URL Support</li>
-  <li><strong>More...</strong></li>
-</ul>
-
-<h3>How Do I Use It:</h3>
-<ul>
-<li>Set preferences</li>
-<p>Usually this is just a formality.  You should specify your default weight units, and your default currency symbol for your local environment.</p>
-<li>Setup users and permissions</li>
-<p>This module uses the &#039;Modify Templates&#039; permission to allow users to be able to modify the various templates that can be used by this module.  As well, the &#039;Modify Site Preferences&#039; permission is needed to be able to adjust the modules preferences.  In order to have the ability to modify field definitions, categories, or products, your users will need the &#039;Modify Products&#039; permission.</p>
-<li>(optional) Define one or more categories</li>
-<p>This is an optional step, but you will probably want to do this early to prevent having to go back to modify each and every product later.  Adding a category is as simple as clicking on the &#039;Categories&#039; tab in the Product Managers admin section, and clicking &#039;Add A Category&#039;.  From there you will be prompted for a category name.</p>
-<li>(optional) Define one or more custom fields</li>
-<p>This is an optional step.  Custom fields are not needed if this module suits you exactly as it is.  However if you would like to store additional information for each of your products you can create custom fields.  Creating custom fields is similar to creating categories, except that more data is requested.</p>
-<p>Currently only three types of custom fields are available: &#039;textbox&#039;,&#039;checkbox&#039;,and &#039;textarea&#039;.  Select one of these, give your new field a name, and indicate wether that field should be visible to the public in the various views.  Then hit submit</p>
-<li>Create one or more products</li>
-<p>You should create one or more products to display in your website content.  Give each product a name, a price (optional) a weight (optional), a status (draft or published), and some information.  Additionally, you can upload up two images for each product, and specify if the product is taxable.</p>
-<p>If categories are defined, then a checkbox will appear for each defined category.  You can simply click the checkbox fields for each category that this product should belong to.</p>
-<p>If custom fields are defined, then input fields appropriate to the type of custom field will appear and allow you to specify data for each of them.  This data is optional.</p>
-<li>Add the appropriate tags into your page templates or page content</li>
-<p>This can be as simple as adding the <strong>{Products}</strong> tag into the content area of one of your pages, or into your page template.</p>
-<p>If you wish to alter the behaviour of this application from its default, you can do that by adding one or more parameters to the <strong>{Products}</strong> tag.  The complete list of parameters and their behaviour is listed below.  But for example, to display a list of products in a single, existing category, you could use a tag like <code>{Products category=&#039;categoryname&#039;}</code></p>
-</ul>
-<h3>Support</h3>
-<p>This module does not include commercial support.  However there are a number of resources available to help you with it:</p>
-<ul>
-<li>For the latest version of this module, FAQs or to file a bug report, please visit the cms made simple <a href="http://dev.cmsmadesimple.org">Developers Forge</a> and do a search for &#039;Products&#039;</li>
-<li>To obtain commercial support, please send an email to the author at <a href="mailto:calguy1000@cmsmadesimple.org">Robert Campbell</a>.</li>
-<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forms.</a></li>
-<li>For some questions and limited technical support, the author can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
-</ul>';
 $lang['hierarchy'] = 'Gerarchia';
 $lang['hierarchy_position'] = 'Posizione gerarchia';
 $lang['hierarchy_settings'] = 'Configurazioni della Gerarchia';
@@ -390,4 +339,4 @@ $lang['utma'] = '156861353.974349155.1299072468.1299072468.1299074554.2';
 $lang['utmb'] = '156861353';
 $lang['utmz'] = '156861353.1299072468.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmc'] = '156861353';
-?>
\ No newline at end of file
+?>
