@@ -1,11 +1,11 @@
 <?php
-$lang['abbr_length'] = 'L ';
+$lang['abbr_length'] = 'L';
 $lang['abbr_width'] = 'Br';
 $lang['abbr_height'] = 'Hg';
 $lang['add'] = 'Voeg toe';
 $lang['addcategory'] = 'Voeg categorie toe';
 $lang['addfielddef'] = 'Voeg veld toe';
-$lang['adjustable'] = 'Wijzigbaar';
+$lang['adjustable'] = 'Aanpasbaar';
 $lang['addproduct'] = 'Voeg product toe';
 $lang['add_attrib_set'] = 'Voeg attribuut toe';
 $lang['add_category_field'] = 'Koppel veld met categorie: &quot;%s&quot;';
@@ -28,10 +28,10 @@ $lang['any'] = 'Enige';
 $lang['areyousure'] = 'Weet u dit zeker?';
 $lang['areyousure_deleteproduct'] = 'Weet u zeker dat u dit product en alle bijbehorende informatie wilt verwijderen?';
 $lang['ascending'] = 'Oplopend';
-$lang['attribute_name'] = 'Atribuut Naam';
+$lang['attribute_name'] = 'Attribuut Naam';
 $lang['attrib_text'] = 'Tekst';
 $lang['automatic'] = 'Automatisch';
-$lang['btn_setecomhandlers'] = 'Ecommerce Gebeurtenissen instellen';
+$lang['btn_setecomhandlers'] = 'E-commerce Gebeurtenissen instellen';
 $lang['byhierarchytemplates'] = 'Hierarchie Rapport Sjablonen';
 $lang['byhierarchytemplate_addedit'] = 'Hierarchie Rapport Sjabloon toevoegen/aanpassen';
 $lang['cancel'] = 'Annuleren';
@@ -41,8 +41,9 @@ $lang['categoryexists'] = 'Er bestaat al een categorie met deze naam';
 $lang['categorylisttemplates'] = 'Categorie Lijst Sjablonen';
 $lang['categorylisttemplate_addedit'] = 'Categorie Lijst Sjabloon toevoegen/aanpassen';
 $lang['centimeters'] = 'Centimeter';
+$lang['cd_autocomplete'] = 'Type de eerste letters van de bedrijfsnaam';
 $lang['checkbox'] = 'Vinkvakje';
-$lang['confirm_copyoptions'] = 'Any existing options for this item will be replaced. Are you sure you want to continue?';
+$lang['companydir_reference'] = 'Company Directory Item Id';
 $lang['confirm_delete_hierarchy_node'] = 'Bent u zeker dat u deze node wilt verwijderen?  Elk product wat gebruik maakt van deze node zal niet meer onder een hi&euml;rarchie vallen.';
 $lang['confirm_deletealloptions'] = 'Weet u zeker dat u alle opties voor dit product wilt verwijderen?';
 $lang['confirm_import'] = 'Bent u zeker dat u dit wilt uitvoeren?\n\nVerkeerde instellingen of een verkeerd configuratiebestand kan het hele systeem in de war brengen. Wat resulteert in een niet werkende producten module.';
@@ -54,25 +55,23 @@ $lang['copy_category'] = 'Categorie kopieren';
 $lang['copy_options_from'] = 'Kopieer alle opties van';
 $lang['createddate'] = 'Aangemaakt op';
 $lang['current_value'] = 'Huidige waarde';
-$lang['data'] = 'Data ';
+$lang['data'] = 'Gegevens';
 $lang['default'] = 'Standaard';
 $lang['defaulttemplates'] = 'Standaard Sjablonen';
 $lang['default_template_notice'] = '<strong>Opmerking:</strong> De inhoud van deze tekstblokken worden gebruikt om de standaard waarden van een template op te slaan. Als u op de knop &quot;Voeg template toe&quot; klikt dan zullen deze standaard waarden in het nieuwe template worden opgenomen.';
 $lang['delete'] = 'Verwijderen';
 $lang['delete_all'] = 'Verwijder alles';
-$lang['delete_attribset'] = 'Attribuut verwijderen';
+$lang['delete_attribute'] = 'Verwijder Attribuut';
 $lang['delete_hierarchy_item'] = 'Verwijder Hierarchie Item';
 $lang['descending'] = 'Aflopend';
 $lang['description'] = 'Omschrijving';
 $lang['destination'] = 'Bestemming';
-$lang['details'] = 'Details ';
 $lang['detailtemplates'] = 'Detail Sjablonen';
 $lang['detailtemplate_addedit'] = 'Toevoegen/wijzigen Detail Sjabloon';
 $lang['dimensions'] = 'Dimensie';
 $lang['disabled'] = 'Uitgeschakeld';
 $lang['down'] = 'Naar beneden';
 $lang['draft'] = 'Concept';
-$lang['dropdown'] = 'Dropdown ';
 $lang['dropdown_options'] = 'Dropdown opties <em>(wordt alleen toegepast op velden)</em><br/><br/><em>(1 invoer per regel)</em>';
 $lang['edit'] = 'Aanpassen';
 $lang['edit_attribset'] = 'Wijzig attribuut';
@@ -81,20 +80,20 @@ $lang['edit_attribsets_for'] = 'Attribuut Groep aanpasen voor';
 $lang['edit_attributes'] = 'Attribuut aanpassen';
 $lang['edit_category'] = 'Categorie aanpassen';
 $lang['edit_category_fields'] = 'Categorie Velden aanpassen';
-$lang['edit_hierarochy_item'] = 'Wijzig Hierarchy Item';
+$lang['edit_hierarchy_item'] = 'Wijzig Hierarchie Item';
 $lang['edit_notes'] = 'Wijzig Opmerkingen';
 $lang['edit_option_notes'] = 'Wijzig Optie Opmerkingen';
 $lang['edit_options'] = 'Wijzig Product Opties';
-$lang['edit_product'] = 'Wijzig Item ';
+$lang['edit_product'] = 'Wijzig Item';
 $lang['errors'] = 'Fouten';
 $lang['error_attribset_exists'] = 'Er bestaat al een attribuut met deze naam';
 $lang['error_dberror'] = 'Database fout';
+$lang['error_delete_lastrow'] = 'De laatste regel kan zo niet worden verwijderd';
 $lang['error_duplicate_sku'] = 'Dubbele Uitlevereenheid waarde gevonden';
 $lang['error_fieldvalue_empty'] = 'De Veld Waarde mag niet leeg zijn';
-$lang['error_fileformat'] = 'File Format probleem';
+$lang['error_fileformat'] = 'Bestand Format probleem';
 $lang['error_filenotfound'] = 'Bestand niet gevonden';
 $lang['error_fileopen'] = 'Probleem met openen van bestand %s';
-$lang['error_invalidparamcount'] = 'Invalid (or not matching) parameter count';
 $lang['error_invalidparent'] = 'Ongeldige Ouder (een hierarchie node kan niet zijn eigen ouder zijn)';
 $lang['error_invalid_name'] = 'De aangepaste veld waarde die u heeft ingevoerd klopt niet (er staan ook niet alfnumerieke karakters in)';
 $lang['error_invalid_value'] = 'Ongeldige waarde opgegeven';
@@ -110,12 +109,8 @@ $lang['error_product_aliasused'] = 'De genoemde alias is al in gebruik';
 $lang['error_product_nameused'] = 'Er bestaat al een product met deze naam';
 $lang['error_product_notfound'] = 'Het gevraagde product kan niet worden gevonden';
 $lang['error_product_skuused'] = 'Deze Uitlevereenheid is al in gebruik door een ander product';
-$lang['error_product_skuused_atrow'] = 'That SKU value at row %d is already in use by another item';
 $lang['error_price_adjustment'] = 'Ongeldige prijs aanpassing van item %s';
-$lang['erorr_qoh_negative_atrow'] = 'Quantity on hand cannot be negative at row %d';
 $lang['error_sku_required'] = 'Voer een unieke SKU in';
-$lang['error_sku_required_atrow'] = 'Please enter a unique SKU on row %d';
-$lang['error_text_empty_atrow'] = 'The text field at row %d cannot be empty';
 $lang['error_upload_failed'] = 'Upload mislukt: %s';
 $lang['exclude_categories'] = 'Sluit producten in de geselecteerde categori&euml;n uit van de resultaten';
 $lang['expire_six_months'] = 'Na zes maanden';
@@ -124,9 +119,6 @@ $lang['expire_two_year'] = 'Na twee jaar';
 $lang['export_to_csv'] = 'Export naar CSV';
 $lang['exportattribs'] = 'Export Attributen';
 $lang['exportcats'] = 'Export Categori&euml;n';
-$lang['exportdelim'] = 'Export field Delimiter';
-$lang['exportdraft'] = 'Export Draft Items';
-$lang['exportfields'] = 'Export Custom Fields';
 $lang['extra1'] = 'Extra veld 1';
 $lang['extra2'] = 'Extra veld 2';
 $lang['field'] = 'Veld';
@@ -134,20 +126,16 @@ $lang['fields'] = 'Velden';
 $lang['fielddef'] = 'Velddefinitie';
 $lang['fielddefs'] = 'Velddefinities';
 $lang['file'] = 'Bestand';
-$lang['filter'] = 'Filter ';
 $lang['filterinuse'] = 'in werking';
-$lang['filters'] = 'Filters ';
 $lang['firstpage'] = '<<';
 $lang['general_settings'] = 'Algemene instellingen';
 $lang['go'] = 'Ga naar';
 $lang['hierarchy'] = 'Hierarchie';
 $lang['hierarchy_position'] = 'Hierarchie Positie';
 $lang['hierarchy_settings'] = 'Hierachie instellingen';
-$lang['id'] = 'Id ';
 $lang['imagetext'] = 'Afbeelding';
 $lang['image_handling_settings'] = 'Instellingen afbeelding afhandeling';
 $lang['import_from_csv'] = 'Importeer producten vanuit een CSV file';
-$lang['inches'] = 'Inches ';
 $lang['include_children'] = 'Inclusief onderliggenden?';
 $lang['info_alnumonly'] = 'Alleen alfanumerieke karakters. Geen witruimte, aanhalingstekens of letter/nummer combinaties';
 $lang['info_attribtemplate'] = 'Mogelijke waarden zijn: {$attrib_text}, {$attrib_adjust}, {$currency_symbol}';
@@ -156,9 +144,6 @@ $lang['info_autowatermark'] = 'De watermerk instellingen zijn afkomstig uit de C
 $lang['info_batchsize'] = 'Stel het aantal regels om uit te voeren per &#039;batch&#039; in. Nadat een batch is voltooid, zal de importer worden doorverwezen en doorgaan met de operatie. Als u verwacht dat er mogelijk geheugenfouten gaan ontstaan of time-outproblemen door het hoge aantal regels per keer, dan kunt u beter contact opnemen met uw hostingprovider of dit nummer lager instellen.';
 $lang['info_cart_module_params'] = 'Deze parameters worden doorgegeven aan de geselecteerde cart module vanuit het  product uitgebreid en opsomming displays';
 $lang['info_copy_attribsets'] = 'Deze actie zal de attributensets kopie&euml;ren (exclusief sku waardes) van een ander product';
-$lang['info_clearattribs'] = 'Only applicable when updating existing items, this will clear all attribute information from the database for items before creating new ones';
-$lang['info_clearcategories'] = 'Only applicable when updating existing items, this will clear all category memberships befoe creating new ones';
-$lang['info_clearfields'] = 'Only applicable when updating existing items, this will clear all fields befoe creating field values';
 $lang['info_createfields'] = 'Maak onbekende productvelden automatisch aan? <em>(Ze worden dan aangemaakt als tekstveld)</em>';
 $lang['info_createcategories'] = 'Maak automatisch een productcategorie aan die voorkomt in het CSV file als deze nog niet bestaat';
 $lang['info_createhierarchy'] = 'Maak automatisch een product hi&euml;rarchie aan die voorkomt in het CSV file als deze nog niet bestaan';
@@ -178,7 +163,6 @@ $lang['info_prodnotfound'] = 'Deze optie bepaald het gedrag van de website wanne
 $lang['info_publicfield'] = 'Publieke velden zijn zichtbaar voor het publiek';
 $lang['info_reorder_content'] = 'Deze actie staat het slepen van individuele items in de boomstructuur toe. Zo kunt u de volgorde aanpassen waarin de items worden weergeven in de hi&euml;rarchische weergave.';
 $lang['info_setecomhandlers'] = 'Deze knop garandeert dat de gebeurtenissen voor e-commerceactiviteiten juist zijn ge&iuml;nstalleerd. Dit is handig wanneer de productenmodule de beschikbare hoeveelheden bij wil houden, maar de gebeurtenishandlers niet zijn aangemaakt tijden de installatie of upgrade.';
-$lang['label'] = 'Label ';
 $lang['label_skip'] = 'Sla over';
 $lang['label_overwrite'] = 'Overschrijven';
 $lang['label_update'] = 'Bijwerken';
@@ -190,11 +174,8 @@ $lang['modifieddate'] = 'Aangepast op';
 $lang['module_description'] = 'Een module voor het managen van een productcatalogus. De producten zijn voorzien van een prijs, een foto, etc. Ook is er een mogelijkheid voor een winkelwagen te maken.';
 $lang['move_down'] = 'Verschuif naar beneden';
 $lang['move_up'] = 'Verschuif naar boven';
+$lang['msg_category_deleted'] = 'Categorie verwijderd';
 $lang['msg_eventhandlers_created'] = 'Gebeurtenishandlers gecree&euml;rd.';
-$lang['msg_optionscopied'] = 'Product options copied (but not saved yet)';
-$lang['msg_options_deleted'] = 'Product options deleted for product %d';
-$lang['msg_options_saved'] = 'Product options saved';
-$lang['msg_productcopied'] = 'Item successfully copied.  You are now editing the copy.  Any sku information in the item, and/or attributes has been cleared';
 $lang['name'] = 'Naam';
 $lang['needpermission'] = 'U heeft niet de vereiste rechten: %s';
 $lang['new_category_name'] = 'Nieuwe Categorie Naam';
@@ -211,64 +192,13 @@ $lang['operation_complete'] = 'Operatie uitgevoerd';
 $lang['page'] = 'Pagina';
 $lang['page_of'] = 'Pagina %s van %s';
 $lang['page_limit'] = 'Pagina Limiet';
-$lang['param_action'] = 'Specify the behaviour of the module.  Possible values are:
-<ul>
-  <li>hierarchy -- Display an item list by hierarchy</li>
-  <li>categorylist - Display a list of item categories</li>
-  <li><em>default</em> - Display a summary of items</li>
-  <li>details - Display a detail view of a single item</li>
-  <li>fieldlist - Display a list of values from a specified field.
-     <p>
-&nbsp;&nbsp;&nbsp;&nbsp;- This action can be used to create a navigation from the values of a specific field.  i.e:  you could create a custom dropdown field called &amp;quot;color&amp;quot; and then create a navigation based on the different colors.
-     </p>
-  </li>
-  <li>search - Display a form to allow searching items on various criterium</li>
-<li>ajax_propval - Return a json encoded list of property values matching the criteria specified.  This action is intended to be used via ajax, and should be called with the showtemplate=false parameter on the URL.</li>
-</ul> ';
-$lang['param_category'] = 'When used in the <em>default</em> summary mode, this parameter, which should match the name of an existing category will be used to display only those items that are in that categoory. (a comma seperated list can be supplied).  This parameter can also be used with the categorylist action to limit the output to the specified item categories. ';
 $lang['param_categoryfield'] = 'Alleen van toepassing op de &quot;categorylist&quot; actie, deze parameter kan gebruikt worden om categori&euml;n te filteren op basis van de waarde van het categorieveld. Het werkt niet in combinatie met de &quot;category&quot; of de &quot;category_id&quot; parameters. De syntax van deze parameter is een kommagescheiden lijst met veldnamen en veldwaarden.  Bijvoorbeeld:  categorylist=&quot;veldnaam:waarde,veldnaam 2:waarde 2&quot;';
-$lang['param_categorylisttemplate'] = 'Useful only with the categorylist action, this parameter indicates the template that should be used for the display.  If no value is specified then the current default template of that type is used.';
-$lang['param_categorylistdtltemplate'] = 'Useful only with the categorylist actions, this parameter indicates the template that should be used for the display of the category details.  This uses a category list template..  If no value is specified then the current default template of that type is used. ';
-$lang['param_detailpage'] = 'This specifies the pageid or alias that should be used to display the detail report.  It can be used with the <em>default</em> or search actions.  This option is not compatible with pretty urls of any sort. ';
-$lang['param_detailtemplate'] = 'This parameter specifies the template that should be used for the detail mode display.  If no value is specified, then the current default template of that type is used.  This parameter has no use when pretty urls are enabled. ';
-$lang['param_excludecat'] = 'Applicable only to the default (summary) view, this parameter will allow excluding products that are in a specific category from the result. A comma separated list of category names is allowed. This parameter can work in conjunction with the category parameter to provide a list of the products that are in this category, but not in that category ';
-$lang['param_field'] = 'Used in the <em>fieldlist</em> and the <em>ajax_propval</em> actions. In the fieldlist action, this parameter is required to specify the name of a user defined property to create a list from.  In the ajax_propval action this parameter is used to specify which field to use to extract a list of values.  Any valid field names are accepted (though only text field and dropdown field names will work properly.  Additionally the special values ::name::, ::sku::, and ::alias:: can be specified to return values from the item name, sku and alias respectively. ';
-$lang['param_fieldval'] = 'Used in the <em>default</em> and <em>ajax_propval</em> actions, this parameter allows specifying a field value to limit results by.  In the default value these special values are accepted: &amp;quot;::null::&amp;quot; &amp;quot;::notnull::&amp;quot;. In the ajax_propval action this field is expected to contain only a few letters, to indicate a small filter.  i.e: fieldval=b to return all field values that begin with the letter b. ';
-$lang['param_hierarchy'] = 'Useed in the <em>default</em> and hierachy actions this parameter has two uses.  When used in the default (summary) action, this parameter specifies that only items in that location of the hierarchy should be displayed.  Wildcard character can be used so that you can specify parent/child relationships as well.  i.e {Products hierarchy=&#039;trucks*&#039;} will create a summary report of all trucks, including the children in the hierarchy.  Similarly, {Products hierarchy=&#039;*trucks&#039;} will display a summary report of all trucks, and all items beloging to any parent in the hierarchy.  A comma separated list of expressions can be supplied.  i.e: {Products action=hierarchy hierarchy=&#039;trucks,cars&#039;} ';
-$lang['param_hierarchytemplate'] = 'This parameter specifies the template that should be used for the hierarchy display. If no value is specified, then the current default template of that type is used. ';
-$lang['param_inline'] = 'Useful only with the search action, this parameter specifies that the output of the summary view should be displayed inline ';
-$lang['param_notpretty'] = 'Thie parameter specifies a comma separated list of actions to which pretty urls should not be generated.  i.e: notpretty=hierarchy,default will not generate pretty urls to hierarchy, or summary (default) actions, but will allow generation of pretty urls to detail views.  As a special vaue &quot;all&quot; can be used to specify that no pretty urls should be generated';
-$lang['param_pagelimit'] = 'Useful only with the <em>default</em> action, this parameter specifies how many items should be listed on each page.';
-$lang['param_parent'] = 'Useful only in the <em>hierarchy</em> action, this parameter specifies the hierarchy id of the starting location of the report. ';
-$lang['param_parents'] = 'Useful only in the <em>hierarchy</em> action, this parameter specifies a comma separated list of hierarchy names that specify to create numerous heirarchy trees from the specified location(s).  Hierarchy names must be unique, and not contain any special chars.';
+$lang['param_excludecat'] = 'Applicable only to the default (summary) view, this parameter will allow excluding products that are in a specific category from the result. A comma separated list of category names is allowed. This parameter can work in conjunction with the category parameter to provide a list of the products that are in this category, but not in that category';
 $lang['param_productid'] = 'Heeft alleen zin in de uitgebreide sjabloon. Deze parameter geeft aan welk product te gebruiken bij het weergeven.';
-$lang['param_productlist'] = 'Applicable only to the default (summary) view, this parameter allows specifying a comma separated list of integer product ids to display.  No pagination or sorting is performed on these values, and if specified the other filtering parameters to the summary view are ignored. ';
 $lang['param_resultpage'] = 'Applicable only to the search action, this parameter specifies a page id or alias to use to display the search results';
 $lang['param_searchfield'] = 'Alleen van toepassing op de zoekacties, deze parameter kan een kommagescheiden lijst bevatten met daarin veldnamen die kunnen worden toegevoegd in de zoekactie.';
 $lang['param_searchformtemplate'] = 'Alleen van toepassing op de zoekacties, deze parameter staat nu om een niet standaard zoeksjabloon te gebruiken';
 $lang['param_showall'] = 'Applicable only to the categorylist action, if this parameter is set to a non 0 integer value all categories (even those without products) will be displayed.';
-$lang['param_sortorder'] = 'Specify the order of sorted fields in summary view.  Possible values are:
-<ul>
-  <li><strong>asc</strong> -- Ascending order</li>
-  <li>desc -- Descending order</li>
-</ul>';
-$lang['param_sortby'] = 'Applicable in the summary, categorylist or search actions, this parameter determines the sorting of the output.  Possible values are:
-<ul>
-  <li><strong>item_name</strong></li>
-  <li>id -- The item id</li>
-  <li>weight -- The item weight</li>
-  <li>price -- The item base price</li>
-  <li>status -- Draft or published</li>
-  <li>random -- Display in random order on each request</li>
-  <li>created -- The creation date for this company record</li>
-  <li>modified -- The modified date for this company record</li>
-  <li>f:fieldname -- Allows sorting by values of custom fields.</li>
-</ul>
-<p>The category list view supports only a few specific sorting options:</p>
-<ul>
-  <li>id -- The category id.</li>
-  <li><strong>name</strong> -- The category name.</li>
-</ul> ';
 $lang['param_sorttype'] = 'Alleen van toepassing op de standaard samenvattingsweergave, deze parameter kan worden gebruikt om waardes om te zetten naar een ander type voor sortering.  Geldige waarden zijn STRING, SIGNED en UNSIGNED. Als dit niet is opgegeven dan zal standaard STRING worden gekozen.';
 $lang['param_summarypage'] = 'Alleen van toepassing op action=hierarchy, staat toe op een pagina id of alias op te geven die moet worden gebruikt voor de links in de samenvattingsweergave.';
 $lang['param_summarytemplate'] = 'Deze parameter geeft aan welke opsomming sjabloon er gebruikt moet worden. Als er geen geselecteerd wordt dan word de standaard sjabloon gebruikt.';
@@ -281,7 +211,7 @@ $lang['price'] = 'Prijs';
 $lang['price_adjustment'] = 'Prijswijziging';
 $lang['prefix_copyof'] = 'Kopieer van';
 $lang['prevpage'] = '<';
-$lang['product'] = 'Product ';
+$lang['product'] = 'Product';
 $lang['productname'] = 'Productnaam';
 $lang['products'] = 'Producten';
 $lang['product_detail_settings'] = 'Product Detail Instellingen';
@@ -291,7 +221,6 @@ $lang['product_hierarchy'] = 'Producthierarchie';
 $lang['product_info'] = 'Productinformatie';
 $lang['product_manager'] = 'Productmanager';
 $lang['progress'] = 'Voortgang';
-$lang['prompt'] = 'Prompt ';
 $lang['prompt_add_attribset'] = 'Toevoegen/Wijzigen Attributen Set';
 $lang['prompt_allowed_filetypes'] = 'Sta het uploaden van bestanden toe met deze extensies (voor niet-afbeeldingen)';
 $lang['prompt_allowed_imagetypes'] = 'Sta het uploaden van bestanden toe met deze extensies (voor afbeeldingen)';
@@ -303,11 +232,8 @@ $lang['prompt_autopreviewimg_size'] = 'Maximale afmeting (grootste zijde) van de
 $lang['prompt_autowatermark'] = 'Plaats automatisch een watermerk op de afbeeldingen';
 $lang['prompt_applicable'] = 'Schakel standaard in voor alle nieuwe producten';
 $lang['prompt_batchsize'] = 'Volume grootte';
-$lang['prompt_cart_module'] = 'Cart Module ';
-$lang['prompt_cart_module_params'] = 'Cart Module Parameters ';
-$lang['prompt_clearattribs'] = 'Clear attributes on update';
-$lang['prompt_clearcategories'] = 'Clear categories on update';
-$lang['prompt_clearfields'] = 'Clear fields on update';
+$lang['prompt_cart_module'] = 'Cart Module';
+$lang['prompt_cart_module_params'] = 'Cart Module Parameters';
 $lang['prompt_createcategories'] = 'Maak categori&euml;n';
 $lang['prompt_createfields'] = 'Maak product velden?';
 $lang['prompt_createhierarchy'] = 'Maak product hi&euml;rarchie';
@@ -336,7 +262,6 @@ $lang['prompt_prettyhierurls'] = 'Gebruik Pretty URL&#039;s voor de hie&auml;rch
 $lang['prompt_prod_detailpage'] = 'Standaard Pagina voor Product Detail Overzichten';
 $lang['prompt_products_matching'] = 'Producten gelijk aan %s';
 $lang['prompt_sku_required'] = 'Een SKU is vereist voor alle producten en attributen';
-$lang['prompt_summary_newdefault'] = 'Use new summary view';
 $lang['prompt_summarypagelimit'] = 'Standaard paginalimiet in samenvattingsmodus';
 $lang['prompt_summarysortorder'] = 'Standaard sorteervolgorde in samenvattingsmodus';
 $lang['prompt_summarysorting'] = 'Standaard veldvolgorde in samenvattingsmodus';
@@ -351,7 +276,6 @@ $lang['published'] = 'Gepubliceerd';
 $lang['quantity_on_hand'] = 'Beschikbare hoeveelheid';
 $lang['random'] = 'Willekeurig';
 $lang['reorder_hierarchy'] = 'Herorder hierarchie';
-$lang['reset'] = 'Reset ';
 $lang['resettofactory'] = 'Reset naar standaardinstellingen';
 $lang['return'] = 'Keer terug';
 $lang['return_to_top'] = 'Ga terug naar de bovenkant van de pagina';
@@ -362,15 +286,14 @@ $lang['search_name'] = 'Zoekeigenschap Naam';
 $lang['search_price'] = 'Prijs marge';
 $lang['searchtemplate_addedit'] = 'Toevoegen/wijzigen Zoekformulier sjabloon';
 $lang['searchtemplates'] = 'Zoek Sjablonen';
-$lang['select_all'] = 'Selecteer akkes';
+$lang['select_all'] = 'Selecteer alles';
 $lang['select_one'] = 'Kies &eacute;&eacute;n';
 $lang['setdraft'] = 'Markeer als concept';
 $lang['setpublished'] = 'Markeer als gepubliceerd';
-$lang['sku'] = 'Uitlevereenheid ';
+$lang['sku'] = 'Uitlevereenheid';
 $lang['sort_by'] = 'Sorteer op';
 $lang['sort_order'] = 'Sorteervolgorde';
 $lang['source'] = 'Bron';
-$lang['status'] = 'Status ';
 $lang['submit'] = 'Versturen';
 $lang['subscription'] = 'Lidmaatschap';
 $lang['subscr_expiry'] = 'Verlopen';
@@ -389,18 +312,13 @@ $lang['taxable'] = 'Belastbaar';
 $lang['test'] = 'Testen';
 $lang['textarea'] = 'Tekstruimte';
 $lang['textbox'] = 'Tekst Invoer';
-$lang['title_adjustment'] = 'Enter an adjustment from the base price for the product options.  Syntax is [+-]#.##';
-$lang['title_attribute_text'] = 'Enter a brief description for this product option';
 $lang['title_byhierarchy_dflttemplate'] = 'Standaard nieuw Hierachie Rapport Sjabloon';
 $lang['title_categorylist_dflttemplate'] = 'Standaard nieuw Categorielijst Sjabloon';
 $lang['title_detail_dflttemplate'] = 'Standaard nieuw Detail Sjabloon';
-$lang['title_qoh'] = 'Optionally specify a quantity on hand for this product option.  Note for quantity adjustments to be automatic the SKU field must also be populated';
 $lang['title_search_dflttemplate'] = 'Standaard nieuw Zoek Sjabloon';
-$lang['title_sku'] = 'The SKU is used for managing quantity on hand, and promotions for product options.';
 $lang['title_summary_dflttemplate'] = 'Standaard nieuwe Samenvatting Sjabloon';
-$lang['type'] = 'Type ';
 $lang['up'] = 'Omhoog';
-$lang['update'] = 'Bijwerken ';
+$lang['update'] = 'Bijwerken';
 $lang['upload'] = 'Selecteer een bestand om te uploaden';
 $lang['url_alias'] = 'Alias in pagina url';
 $lang['valid'] = 'Correct';
@@ -408,13 +326,12 @@ $lang['value'] = 'Waarde';
 $lang['values'] = 'Waarden';
 $lang['view'] = 'Bekijk';
 $lang['viewable_fields'] = 'Selecteer velden om in het tabel te tonen';
-$lang['warn_edit_product_options'] = 'Each product option must have a unique string.  If SKU is required then it must be unique across the entire system.';
 $lang['watermark_location'] = 'Plaats Watermerk';
 $lang['weight'] = 'Gewicht';
 $lang['with_selected'] = 'Met geselecteerden';
 $lang['yes'] = 'Ja';
-$lang['utma'] = '156861353.1652442735.1375624076.1375624076.1375624076.1';
-$lang['utmz'] = '156861353.1375624076.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
-$lang['utmb'] = '156861353';
+$lang['utma'] = '156861353.1286701619.1382894910.1382894910.1382894910.1';
+$lang['utmz'] = '156861353.1382894910.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/search.php|utmcmd=referral';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
