@@ -82,7 +82,7 @@ class hierarchy_ops
                   ON ph.id = pth.hierarchy_id
                   LEFT OUTER JOIN '.cms_db_prefix().'module_products pr
                   ON pth.product_id = pr.id';
-	if( !$all ) $query .' AND pr.status = '.$db->qstr('published');
+	if( !$all ) $query .= ' AND pr.status = '.$db->qstr('published');
 	$query .= ' GROUP BY ph.id
                    ORDER BY ph.hierarchy';
 	$tmp = $db->GetAll($query);
