@@ -57,10 +57,8 @@ final class product_utils
     $items[$mod->Lang('dimensions')] = 'dimensions';
     $items[$mod->Lang('subscription')] = 'subscription';
     $items[$mod->Lang('quantity_on_hand')] = 'quantity';
-//     $cdmod = cms_utils::get_module('CompanyDirectory','1.19');
-//     if( is_object($cdmod) ) {
-//       $items[$mod->Lang('companydir_reference')] = 'companydir';
-//     }
+    $cdmod = cms_utils::get_module('CompanyDirectory','1.19');
+    if( is_object($cdmod) ) $items[$mod->Lang('companydir_reference')] = 'companydir';
     return array_flip($items);
   }
 
@@ -294,10 +292,16 @@ final class product_utils
 	  $tmp = explode("\n",$row['options']);
 	  $tmp2 = array();
 	  foreach( $tmp as $one ) {
-	    $one = trim($one);
-	    $tmp2[$one] = $one;
+	    $key = $value = $one = trim($one);
+	    if( !$one ) continue;
+	    if( strpos($one,'|') !== FALSE ) {
+	      list($key,$value) = explode('|',$one);
+	      $key = trim($key);
+	      $value = trim($value);
+	    }
+	    $tmp2[$key] = $value;
 	  }
-	  $onerow->options = $tmp2;
+	  $onerow->options = array_flip($tmp2);
 	  $onerow->max_length = $row['max_length'];
 	  
 	  $entryarray[] = $onerow;
