@@ -86,10 +86,7 @@ final class productsCsvImporter
 
   private function _setError($tmp)
   {
-    if( !is_array($this->_errors) )
-      {
-	$this->_errors = array();
-      }
+    if( !is_array($this->_errors) ) $this->_errors = array();
     $this->_errors[] = $this->_linenum.': '.$tmp;
   }
 
@@ -135,9 +132,7 @@ final class productsCsvImporter
     $this->_line = $tmp;
     $this->_linenum++;
     $this->_record = cge_array::smart_explode($this->_line,$this->_delim);
-    if( endswith($tmp,$this->_delim) ) {
-      $this->_record[] = '';
-    }
+    if( endswith($tmp,$this->_delim) ) $this->_record[] = '';
     return TRUE;
   }
 
@@ -148,27 +143,17 @@ final class productsCsvImporter
       $db = cmsms()->GetDb();
       $query = 'SELECT id,name,type FROM '.cms_db_prefix().'module_products_fielddefs';
       $tmp = $db->GetArray($query);
-      if( is_array($tmp) ) {
-	$this->_field_map = cge_array::to_hash($tmp,'name');
-      }
-    }
-    if( is_array($this->_field_map) && isset($this->_field_map[$name]) ) {
-      return $this->_field_map[$name]['id'];
+      if( is_array($tmp) ) $this->_field_map = cge_array::to_hash($tmp,'name');
     }
+    if( is_array($this->_field_map) && isset($this->_field_map[$name]) ) return $this->_field_map[$name]['id'];
     return FALSE;
   }
 
 
   private function _getFieldType($name)
   {
-    if( !is_array($this->_field_map) )
-      {
-	$tmp = $this->_getFieldId($name);
-      }
-    if( is_array($this->_field_map) && isset($this->_field_map[$name]) )
-      {
-	return $this->_field_map[$name]['type'];
-      }
+    if( !is_array($this->_field_map) ) $tmp = $this->_getFieldId($name);
+    if( is_array($this->_field_map) && isset($this->_field_map[$name]) ) return $this->_field_map[$name]['type'];
     return FALSE;
   }
 
@@ -179,11 +164,20 @@ final class productsCsvImporter
     $query = 'SELECT value FROM '.cms_db_prefix().'module_products_fieldvals WHERE product_id = ? AND fielddef_id = ?';
     $tmp = $db->GetOne($query,array($product_id,$fid));
     if( $tmp ) {
-      $query = 'UPDATE '.cms_db_prefix().'module_products_fieldvals SET value = ? WHERE product_id = ? AND fielddef_id = ?';
-      $dbr = $db->Execute($query,array($val,$product_id,$fid));
+      if( $val != '' ) {
+	$query = 'UPDATE '.cms_db_prefix().'module_products_fieldvals SET value = ? WHERE product_id = ? AND fielddef_id = ?';
+	$dbr = $db->Execute($query,array($val,$product_id,$fid));
+      }
+      else {
+	$query = 'DELETE FROM '.cms_db_prefix().'module_products_fieldvals WHERE product_id = ? AND fielddef_id = ?';
+	$dbr = $db->Execute($query,array($val,$product_id,$fid));
+      }
     } else {
-      $query = 'INSERT INTO '.cms_db_prefix().'module_products_fieldvals (value, product_id, fielddef_id) VALUES (?,?,?)';
-      $dbr = $db->Execute($query,array($val,$product_id,$fid));
+      $dbr = true;
+      if( $val != '' ) {
+	$query = 'INSERT INTO '.cms_db_prefix().'module_products_fieldvals (value, product_id, fielddef_id) VALUES (?,?,?)';
+	$dbr = $db->Execute($query,array($val,$product_id,$fid));
+      }
     }
     if( !$dbr ) {
       $this->_setError('Problem inserting field value for field '.$fid);
@@ -195,20 +189,13 @@ final class productsCsvImporter
 
   private function _getCategoryId($name)
   {
-    if( !is_array($this->_category_map) )
-      {
-	$db = cmsms()->GetDb();
-	$query = 'SELECT id,name FROM '.cms_db_prefix().'module_products_categories';
-	$tmp = $db->GetArray($query);
-	if( is_array($tmp) )
-	  {
-	    $this->_category_map = cge_array::to_hash($tmp,'name');
-	  }
-      }
-    if( is_array($this->_category_map) && isset($this->_category_map[$name]) )
-      {
-	return $this->_category_map[$name]['id'];
-      }
+    if( !is_array($this->_category_map) ) {
+      $db = cmsms()->GetDb();
+      $query = 'SELECT id,name FROM '.cms_db_prefix().'module_products_categories';
+      $tmp = $db->GetArray($query);
+      if( is_array($tmp) ) $this->_category_map = cge_array::to_hash($tmp,'name');
+    }
+    if( is_array($this->_category_map) && isset($this->_category_map[$name]) ) return $this->_category_map[$name]['id'];
     return FALSE;
   }
 
@@ -219,10 +206,7 @@ final class productsCsvImporter
     $db = cmsms()->GetDb();
     $query = 'SELECT id,long_name FROM '.cms_db_prefix().'module_products_hierarchy';
     $tmp = $db->GetArray($query);
-    if( is_array($tmp) )
-      {
-	$this->_hierarchy_map = cge_array::to_hash($tmp,'long_name');
-      }
+    if( is_array($tmp) ) $this->_hierarchy_map = cge_array::to_hash($tmp,'long_name');
   }
 
 
@@ -230,17 +214,14 @@ final class productsCsvImporter
   {
     $db = cmsms()->GetDb();
 
-    $query = 'SELECT hierarchy_id FROM '.cms_db_prefix().'module_products_prodtohier
-               WHERE product_id = ?';
+    $query = 'SELECT hierarchy_id FROM '.cms_db_prefix().'module_products_prodtohier WHERE product_id = ?';
     $tmp = $db->GetOne($query,array($product_id));
     if( $tmp ) {
-      $query = 'UPDATE '.cms_db_prefix().'module_products_prodtohier
-                SET hierarchy_id = ? WHERE product_id = ?';
+      $query = 'UPDATE '.cms_db_prefix().'module_products_prodtohier SET hierarchy_id = ? WHERE product_id = ?';
       $dbr = $db->Execute($query,array($hier_id,$product_id));
     }
     else {
-      $query = 'INSERT INTO '.cms_db_prefix().'module_products_prodtohier
-                 (product_id,hierarchy_id) VALUES (?,?)';
+      $query = 'INSERT INTO '.cms_db_prefix().'module_products_prodtohier (product_id,hierarchy_id) VALUES (?,?)';
       $dbr = $db->Execute($query,array($product_id,$hier_id));
     }
     if( !$dbr ) {
@@ -252,51 +233,40 @@ final class productsCsvImporter
 
   private function _getHierarchyId($hier)
   {
-    if( !is_array($this->_hierarchy_map) )
-      {
-	$this->__getHierarchyCache();
-      }
-    if( $this->_getPolicyValue('create_hierarchy') )
-      {
-	if( (is_array($this->_hierarchy_map) && !isset($this->_hierarchy_map[$hier])) ||
-	    !is_array($this->_hierarchy_map) )
-	  {
-	    $db = cmsms()->GetDb();
+    if( !is_array($this->_hierarchy_map) ) $this->__getHierarchyCache();
+    if( $this->_getPolicyValue('create_hierarchy') ) {
+      if( (is_array($this->_hierarchy_map) && !isset($this->_hierarchy_map[$hier])) || !is_array($this->_hierarchy_map) ) {
+	$db = cmsms()->GetDb();
 
-	    // we have everything in memory
-	    // it's just not there
-	    // so we have to create it.
-	    $path = explode(' | ',$hier);
-	    $parent = -1;
-	    $item_order = 1;
-	    $fquery = 'SELECT id FROM '.cms_db_prefix().'module_products_hierarchy WHERE name = ? AND parent_id = ?';
-	    $iquery = 'INSERT INTO '.cms_db_prefix().'module_products_hierarchy (name,parent_id) VALUES (?,?)';
-	    foreach( $path as $one )
-	      {
-		$name = trim($one);
-		$name = trim($name,'"\'');
-		if( empty($name) ) continue;
-		$t_id = $db->GetOne($fquery,array($name,$parent));
-		if( !$t_id )
-		  {
-		    // gotta insert it
-		    $db->Execute($iquery,array($name,$parent));
-		    $t_id = $db->Insert_ID();
-		    $this->_module->UpdateHierarchyPositions();
-		  }
-		$parent = $t_id;
-	      }
+	// we have everything in memory
+	// it's just not there
+	// so we have to create it.
+	$path = explode(' | ',$hier);
+	$parent = -1;
+	$item_order = 1;
+	$fquery = 'SELECT id FROM '.cms_db_prefix().'module_products_hierarchy WHERE name = ? AND parent_id = ?';
+	$iquery = 'INSERT INTO '.cms_db_prefix().'module_products_hierarchy (name,parent_id) VALUES (?,?)';
+	foreach( $path as $one ) {
+	  $name = trim($one);
+	  $name = trim($name,'"\'');
+	  if( empty($name) ) continue;
+	  $t_id = $db->GetOne($fquery,array($name,$parent));
+	  if( !$t_id ) {
+	    // gotta insert it
+	    $db->Execute($iquery,array($name,$parent));
+	    $t_id = $db->Insert_ID();
+	    $this->_module->UpdateHierarchyPositions();
 	  }
-
-	// refresh the memory
-	$this->__getHierarchyCache();
+	  $parent = $t_id;
+	}
       }
 
+      // refresh the memory
+      $this->__getHierarchyCache();
+    }
+
     // return the desired value
-    if( is_array($this->_hierarchy_map) && isset($this->_hierarchy_map[$hier]) )
-      {
-	return $this->_hierarchy_map[$hier]['id'];
-      }
+    if( is_array($this->_hierarchy_map) && isset($this->_hierarchy_map[$hier]) ) return $this->_hierarchy_map[$hier]['id'];
 
     // this ia really a problem
     return FALSE;
@@ -317,10 +287,7 @@ final class productsCsvImporter
   private function _getField($name,$dflt = FALSE)
   {
     $idx = $this->_hasField($name);
-    if( $idx === FALSE )
-      {
-	return $dflt;
-      }
+    if( $idx === FALSE ) return $dflt;
     $val = trim($this->_record[$idx],'\'"');
     return $val;
   }
@@ -341,8 +308,7 @@ final class productsCsvImporter
   {
     $LocaleInfo = localeconv();
     $currency_symbol = '$';
-    if( isset($LocaleInfo['currency_symbol']) && $LocaleInfo['currency_symbol'] != '' )
-      $currency_symbol = $LocaleInfo['currency_symbol'];
+    if( isset($LocaleInfo['currency_symbol']) && $LocaleInfo['currency_symbol'] != '' ) $currency_symbol = $LocaleInfo['currency_symbol'];
 
     $str = trim($str);
     $str = trim($str,$currency_symbol);
@@ -357,14 +323,10 @@ final class productsCsvImporter
   {
     if( !is_array($this->_defs_byindex) ) return FALSE;
     $res = array();
-    for($i = 0; $i < count($this->_defs_byindex); $i++ )
-      {
-	$tmp = trim(trim($this->_defs_byindex[$i]),'\'"');
-	if( startswith($tmp,$prefix) )
-	  {
-	    $res[] = $tmp;
-	  }
-      }
+    for($i = 0; $i < count($this->_defs_byindex); $i++ ) {
+      $tmp = trim(trim($this->_defs_byindex[$i]),'\'"');
+      if( startswith($tmp,$prefix) ) $res[] = $tmp;
+    }
     return $res;
   }
 
@@ -375,54 +337,46 @@ final class productsCsvImporter
     $now = $db->DbTimeStamp(time());
 
     // 0.  Get the field definitions
-    for( $i = 0; $i < count($this->_record); $i++ )
-      {
-	$tmp = trim(trim($this->_record[$i]),'"\'');
-	$byname[$tmp] = $i;
-      }
+    for( $i = 0; $i < count($this->_record); $i++ ) {
+      $tmp = trim(trim($this->_record[$i]),'"\'');
+      $byname[$tmp] = $i;
+    }
     $this->_defs_byname = $byname;
     $this->_defs_byindex = $this->_record;
 
 
     // 1. first make sure we have all the required fields.
     $required_fields = explode(',','#FLAG,#name,#price');
-    foreach( $required_fields as $one )
-      {
-	if( !array_key_exists($one,$this->_defs_byname) )
-	  {
-	    $this->_setError('missing required field '.$one);
-	    return FALSE;
-	  }
+    foreach( $required_fields as $one ) {
+      if( !array_key_exists($one,$this->_defs_byname) ) {
+	$this->_setError('missing required field '.$one);
+	return FALSE;
       }
+    }
 
     // 2. go through and get categories
     // and make sure they exist
-    if( $this->_getPolicyValue('create_categories') )
-      {
-	$cats = $this->_getFieldNamesLike('#CAT');
-	if( is_array($cats) )
-	  {
-	    $fquery = 'SELECT id FROM '.cms_db_prefix().'module_products_categories WHERE name = ?';
-	    $iquery = 'INSERT INTO '.cms_db_prefix()."module_products_categories (name,create_date,modified_date) VALUES (?,$now,$now)";
-	    foreach( $cats as $one )
-	      {
-		$tmp = trim(substr($one,5));
-		$tmp = trim($tmp,'"\'');
-		if( empty($tmp) ) continue;
-		$t_id = $db->GetOne($fquery,array($tmp));
-		if( !$t_id )
-		  {
-		    // oops, gotta add it
-		    $dbr = $db->Execute($iquery,array($tmp));
-		    if( !$dbr )
-		      {
-			$this->_setError('problem creating category '.$tmp);
-			$this->_setError('DEBUG: '.$db->sql.' -- '.$db->ErrorMsg());
-		      }
-		  }
-	      }
+    if( $this->_getPolicyValue('create_categories') ) {
+      $cats = $this->_getFieldNamesLike('#CAT');
+      if( is_array($cats) ) {
+	$fquery = 'SELECT id FROM '.cms_db_prefix().'module_products_categories WHERE name = ?';
+	$iquery = 'INSERT INTO '.cms_db_prefix()."module_products_categories (name,create_date,modified_date) VALUES (?,$now,$now)";
+	foreach( $cats as $one ) {
+	  $tmp = trim(substr($one,5));
+	  $tmp = trim($tmp,'"\'');
+	  if( empty($tmp) ) continue;
+	  $t_id = $db->GetOne($fquery,array($tmp));
+	  if( !$t_id ) {
+	    // oops, gotta add it
+	    $dbr = $db->Execute($iquery,array($tmp));
+	    if( !$dbr ) {
+	      $this->_setError('problem creating category '.$tmp);
+	      $this->_setError('DEBUG: '.$db->sql.' -- '.$db->ErrorMsg());
+	    }
 	  }
+	}
       }
+    }
 
     // 3. then fields
     // and make sure they exist
@@ -523,8 +477,7 @@ final class productsCsvImporter
       // it's a product update.
       $product_id = $t_id;
       $uquery = 'UPDATE '.cms_db_prefix().'module_products
-                 SET product_name = ?, details = ?, price = ?, modified_date = ?, taxable = ?, 
-                     status = ?, weight = ?, sku = ?
+                 SET product_name = ?, details = ?, price = ?, modified_date = ?, taxable = ?, status = ?, weight = ?, sku = ?
                  WHERE id = ?';
       $dbr = $db->Execute($uquery,array($this->_getField('#name'),
 				        $this->_getField('#details',''),
@@ -549,9 +502,7 @@ final class productsCsvImporter
       $hier = implode(' | ',$tmp);
 
       $hid = $this->_getHierarchyId($hier);
-      if( $hid ) {
-	$t = $this->_setHierarchyId($product_id,$hid);
-      }
+      if( $hid ) $t = $this->_setHierarchyId($product_id,$hid);
     }
 
     // get the info for fields
@@ -582,10 +533,7 @@ final class productsCsvImporter
 	  continue;
 	}
 
-	if( $type == 'subscription' ) {
-	  // we don't import these.
-	  continue;
-	}
+	if( $type == 'subscription' ) continue;  // we don't import these.
 
 	if( $type == 'dimensions' ) {
 	  $parts = explode(',',$val);
@@ -640,9 +588,7 @@ final class productsCsvImporter
 
 	if( $insert ) {
 	  // good to insert.
-	  if( !$this->_setFieldValue($product_id,$fid,$val) ) {
-	    continue;
-	  }
+	  if( !$this->_setFieldValue($product_id,$fid,$val) ) continue;
 	}	
       } // fields.
     }
@@ -651,15 +597,13 @@ final class productsCsvImporter
     // and insert them
     // here should we nuke existing categories?
     if( $is_update && $this->_getPolicyValue('clearcategories') ) {
-      $query = 'DELETE FROM '.cms_db_prefix().'module_products_product_categories
-                WHERE product_id = ?';
+      $query = 'DELETE FROM '.cms_db_prefix().'module_products_product_categories WHERE product_id = ?';
       $db->Execute($query,array($product_id));
     }
     $cats = $this->_getFieldNamesLike('#CAT');
     if( is_array($cats) ) {
       $iquery = 'INSERT INTO '.cms_db_prefix()."module_products_product_categories
-                 (product_id,category_id,create_date,modified_date)
-                 VALUES (?,?,$now,$now)"; 
+                 (product_id,category_id,create_date,modified_date) VALUES (?,?,$now,$now)"; 
       foreach( $cats as $one ) {
 	$tmp = explode(':',$one);
 	if( count($tmp) != 2 ) continue;
@@ -670,8 +614,7 @@ final class productsCsvImporter
 	$cid = $this->_getCategoryId($name);
 	if( !(int)$val && !$this->_getPolicyValue('clearcategories') ) {
 	  if( $cid ) {
-	    $dquery = 'DELETE FROM '.cms_db_prefix().'module_products_product_categories 
-                       WHERE product_id = ? AND category_id = ?';
+	    $dquery = 'DELETE FROM '.cms_db_prefix().'module_products_product_categories WHERE product_id = ? AND category_id = ?';
 	    $db->Execute($dquery,array($product_id,$cid));
 	    continue;
 	  }
@@ -682,9 +625,7 @@ final class productsCsvImporter
 	}
 	else if( $val ) {
 	  $dbr = $db->Execute($iquery,array($product_id,$cid));
-	  if( !$dbr ) {
-	    $this->_setError("problem associating category $cid with product $product_id");
-	  }
+	  if( !$dbr ) $this->_setError("problem associating category $cid with product $product_id");
 	}
       }
     }
@@ -692,11 +633,11 @@ final class productsCsvImporter
     // get attributes
     // insert them.
     if( $is_update && $this->_getPolicyValue('clearattribs') ) {
-      $query = 'DELETE FROM '.cms_db_prefix().'module_products_attribs
-                WHERE product_id = ?';
+      $query = 'DELETE FROM '.cms_db_prefix().'module_products_attribs WHERE product_id = ?';
       $db->Execute($query,array($product_id));
     }
-    $tmp = $this->_getField('#ATTRIBS');
+    $tmp = $this->_getField('#OPTIONS');
+    if( empty($tmp) ) $tmp = $this->_getField('#ATTRIBS');
     if( !empty($tmp) ) {
       $attribs = explode('--',$tmp);
       foreach( $attribs as $one ) {
@@ -718,11 +659,9 @@ final class productsCsvImporter
 	// add the attribute value
 	if( !$attr_id ) {
 	  $query = 'INSERT INTO '.cms_db_prefix().'module_products_attribs
-                    (product_id,text,adjustment,sku,qoh)
-                    VALUES (?,?,?,?,?)';
+                    (product_id,text,adjustment,sku,qoh) VALUES (?,?,?,?,?)';
 	  $db->Execute($query,array($product_id,$attr,$adj,$sku,$qoh));
 	}
-      
       } // foreach
     }
 
@@ -734,80 +673,67 @@ final class productsCsvImporter
   {
     $db = cmsms()->GetDb();
 
-    for( $i = 0; $i < count($this->_record); $i++ )
-      {
-	$tmp = trim(trim($this->_record[$i]),'"\'');
-	$byname[$tmp] = $i;
-      }
+    for( $i = 0; $i < count($this->_record); $i++ ) {
+      $tmp = trim(trim($this->_record[$i]),'"\'');
+      $byname[$tmp] = $i;
+    }
     $this->_defs_byname = $byname;
     $this->_defs_byindex = $this->_record;
 
     $required_fields = explode(',','#FLAG,#name,#price');
-    foreach( $required_fields as $one )
-      {
-	if( !array_key_exists($one,$this->_defs_byname) )
-	  {
-	    $this->_setError('missing required field '.$one);
-	    return FALSE;
-	  }
+    foreach( $required_fields as $one ) {
+      if( !array_key_exists($one,$this->_defs_byname) ) {
+	$this->_setError('missing required field '.$one);
+	return FALSE;
       }
+    }
 
     $messages[] = 'found all required fields';
 
     $cats = $this->_getFieldNamesLike('#CAT');
-    if( is_array($cats) )
-      {
-	foreach( $cats as $one )
-	  {
-	    $fquery = 'SELECT id FROM '.cms_db_prefix().'module_products_categories WHERE name = ?';
+    if( is_array($cats) ) {
+      foreach( $cats as $one ) {
+	$fquery = 'SELECT id FROM '.cms_db_prefix().'module_products_categories WHERE name = ?';
 
-	    $tmp = trim(substr($one,5));
-	    $tmp = trim($tmp,'"\'');
-	    if( empty($tmp) ) continue;
-	    $t_id = $db->GetOne($fquery,array($tmp));
-	    if( $t_id )
-	      {
-		$messages[] = 'found existing category '.$tmp;
-	      }
-	    else
-	      {
-		$messages[] = 'unknown category '.$tmp;
-	      }
-	  }
+	$tmp = trim(substr($one,5));
+	$tmp = trim($tmp,'"\'');
+	if( empty($tmp) ) continue;
+	$t_id = $db->GetOne($fquery,array($tmp));
+	if( $t_id ) {
+	  $messages[] = 'found existing category '.$tmp;
+	}
+	else {
+	  $messages[] = 'unknown category '.$tmp;
+	}
       }
+    }
     
     $fields = $this->_getFieldNamesLike('#FIELD');
-    if( is_array($fields) )
-      {
-	$field_types = array_keys(product_utils::get_field_types());
-	$fquery = 'SELECT id FROM '.cms_db_prefix().'module_products_fielddefs WHERE name = ?';
-	foreach( $fields as $one )
-	  {
-	    $tmp = explode(':',$one);
-	    if( count($tmp) != 3 ) continue;
-	    $type = trim(trim($tmp[1]),'"\'');
-	    $name = trim(trim($tmp[2]),'"\'');
-	    if( empty($type) || empty($name) )
-	      {
-		$this->_setError('Invalid field definition: '.$one);
-		return FALSE;
-	      }
-	    if( !in_array($type,$field_types) )
-	      {
-		$this->_setError('Invalid field type: '.$type);
-		return FALSE;
-	      }
-	    $t_id = $db->GetOne($fquery,array($name));
-	    if( !$t_id )
-	      {
-		$messages[] = 'unknown field '.$name;
-	      }
-	    else
-	      {
-		$messages[] = 'found field '.$name.' of type '.$type;
-	      }
-	  }
+    if( is_array($fields) ) {
+      $field_types = array_keys(product_utils::get_field_types());
+      $fquery = 'SELECT id FROM '.cms_db_prefix().'module_products_fielddefs WHERE name = ?';
+      foreach( $fields as $one ) {
+	$tmp = explode(':',$one);
+	if( count($tmp) != 3 ) continue;
+	$type = trim(trim($tmp[1]),'"\'');
+	$name = trim(trim($tmp[2]),'"\'');
+	if( empty($type) || empty($name) ) {
+	  $this->_setError('Invalid field definition: '.$one);
+	  return FALSE;
+	}
+	if( !in_array($type,$field_types) ) {
+	  $this->_setError('Invalid field type: '.$type);
+	  return FALSE;
+	}
+	$t_id = $db->GetOne($fquery,array($name));
+	if( !$t_id ) {
+	  $messages[] = 'unknown field '.$name;
+	}
+	else {
+	  $messages[] = 'found field '.$name.' of type '.$type;
+	}
       }
+    }
 
     return TRUE;
   }
@@ -817,11 +743,14 @@ final class productsCsvImporter
   {
     // make sure we have the required number of fields
     // according to the header.
-    if( $this->_getFieldCount() != $this->_getDefCount() )
-      {
-	$this->_setError('invalid field count ('.$this->_getFieldCount().' of expected '.$this->_getDefCount().')');
-	return FALSE;
-      }
+    if( $this->_getFieldCount() < 2 ) {
+      $this->_setError('invalid field count ('.$this->_getFieldCount().' of expected '.$this->_getDefCount().')');
+      return FALSE;
+    }
+    if( $this->_getField('#name') == '' ) {
+      $this->_setError('missing required field #name');
+      return FALSE;
+    }
 
     return TRUE;
   }
@@ -830,32 +759,30 @@ final class productsCsvImporter
   public function testLine($line,&$messages)
   {
     $pos = strpos($line,'//');
-    if( $pos !== FALSE )
-      {
-	$line = substr($line,0,$pos);
-      }
+    if( $pos !== FALSE ) $line = substr($line,0,$pos);
     $line = trim($line);
     if( empty($line) ) return TRUE;
     
     $res = $this->_setLine($line);
     if( $res === FALSE ) return FALSE;
 
-    if( $this->_linenum == 1 )
-      {
-	$res = $this->_testFirstLine($messages);
+    if( $this->_linenum == 1 ) {
+      $res = $this->_testFirstLine($messages);
+    }
+    else {
+      $flag = strtoupper($this->_getField('#FLAG'));
+      if( $flag == 'P' ) {
+	$res = $this->_testNewProduct($messages);
       }
-    else
-      {
-	if( $this->_getField('#FLAG') == 'P' )
-	  {
-	    $res = $this->_testNewProduct($messages);
-	  }
-	else
-	  {
-	    $this->_setError('invalid field: #FLAG');
-	    $res = FALSE;
-	  }
+      else if( $flag == '' ) {
+	// empty flag, ignore this line.
+	$res = TRUE;
       }
+      else {
+	$this->_setError('invalid field: #FLAG');
+	$res = FALSE;
+      }
+    }
     return $res;
   }
 
@@ -863,11 +790,24 @@ final class productsCsvImporter
   public function handleLine($line)
   {
     // trim off comments.
-    $pos = strpos($line,'//');
-    if( $pos !== FALSE )
-      {
-	$line = substr($line,0,$pos);
+    $pos1 = strpos($line,'//');
+    $pos2 = strpos($line,'http://');
+    $pos3 = strpos($line,'https://');
+    $pos4 = strpos($line,'ftp://');
+    if( $pos1 != FALSE ) {
+      if( $pos2 !== FALSE && $pos2 == $pos1 - 5 ) {
+	// its an http link
       }
+      else if( $pos3 !== FALSE && $pos3 == $pos1 - 6 ) {
+	// its an https link
+      }
+      else if( $pos4 !== FALSE && $pos4 == $pos1 - 4 ) {
+	// its an ftp link
+      }
+      else {
+	$line = substr($line,0,$pos1);
+      }
+    }
     $line = trim($line);
     if( empty($line) ) return TRUE;
 
@@ -879,9 +819,7 @@ final class productsCsvImporter
     else {
       if( $this->_getField('#FLAG') == 'P' ) {
 	$res = $this->_testNewProduct($messages);
-	if( $res ) {
-	  $res = $this->_handleProductLine();
-	}
+	if( $res ) $res = $this->_handleProductLine();
       } else {
 	$this->_setError('invalid field: #FLAG');
 	$res = FALSE;
@@ -897,11 +835,10 @@ final class productsCsvImporter
     // a function to test if this line denotes the start of a new record.
     $valid = array('#FLAG','P','"#FLAG"','"P"');
 
-    foreach( $valid as $one )
-      {
-	$one .= $this->_delim;
-	if( startswith($line,$one) ) return TRUE;
-      }
+    foreach( $valid as $one ) {
+      $one .= $this->_delim;
+      if( startswith($line,$one) ) return TRUE;
+    }
     return FALSE;
   }
 
@@ -912,10 +849,7 @@ final class productsCsvImporter
     $pos1 = ftell($fh);
     
     $line = fgets($fh);
-    if( strpos($line,"\r") === FALSE )
-      {
-	return $line;
-      }
+    if( strpos($line,"\r") === FALSE ) return $line;
     
     // line is probably a crappy mac line.
     $len1 = strlen($line);
@@ -950,9 +884,7 @@ final class productsCsvImporter
 
 } // end of class
 
-
-
 #
 # EOF
 #
-?>
+?>
\ No newline at end of file
