@@ -54,6 +54,16 @@ final class products_resultset
     $this->_query = $query;
   }
 
+  private function _wildcard($str)
+  {
+	$str = str_replace('*','%',$str);
+	$str = str_replace('%%','%',$str);
+	return $str;
+  }
+
+  /**
+   * Given a query object... build the sql query to extract the product data.
+   */
   private function _execute()
   {
 	if( !is_null($this->_rs) ) return;
@@ -67,7 +77,11 @@ final class products_resultset
 
 	$joins[] = cms_db_prefix().'module_products_prodtohier PH ON PH.product_id = C.id';
 
-	if( isset($obj['product_id']) && $obj['product_id'] != '' ) {
+	if( isset($obj['productnamelike']) ) {
+	  $where[] = 'C.product_name LIKE ?';
+	  $qparms[] = $this->_wildcard($obj['productnamelike']);
+	}
+	else if( isset($obj['product_id']) && $obj['product_id'] != '' ) {
 	  $where[] = 'C.id = ?';
 	  $qparms[] = $obj['product_id'];
 	}
@@ -99,6 +113,12 @@ final class products_resultset
 	  $where[] = 'C.id IN ('.implode(',',$list).')';
 	}
 
+	if( isset($obj['desclike']) && $obj['desclike'] ) {
+	  $val = trim($obj['desclike']);
+	  $where[] = 'C.details LIKE ?';
+	  $qparms[] = $this->_wildcard($val);
+	}
+
 	if( isset($obj['status']) && $obj['status'] != '*') {
 	  $val = $obj['status'];
 	  if( startswith($val,'!') ) {
@@ -110,6 +130,34 @@ final class products_resultset
 	  $qparms[] = $val;
 	}
 
+	if( isset($obj['pricerange']) ) {
+	  if( strpos($obj['pricerange'],':') !== FALSE ) {
+		list($min,$max) = explode(':',$obj['pricerange']);
+		if( $min && $max ) {
+		  $min = floatval($min);
+		  $max = floatval($max);
+		  if( $min > $max ) {
+			$tmp = $min;
+			$min = $max;
+			$max = $tmp;
+		  }
+		  $where[] = '(C.price BETWEEN ? AND ?)';
+		  $qparms[] = $min;
+		  $qparms[] = $max;
+		}
+		elseif ( $min ) {
+		  $min = floatval($min);
+		  $where[] = 'C.price >= ?';
+		  $qparms[] = $min;
+		}
+		elseif ( $max ) {
+		  $max = floatval($max);
+		  $where[] = 'C.price <= ?';
+		  $qparms[] = $max;
+		}
+	  }
+	}
+
 	if( isset($obj['hierarchy']) && $obj['hierarchy'] != '' ) {
 	  $subquery = 'SELECT DISTINCT id FROM '.cms_db_prefix().'module_products_hierarchy h WHERE ';
 	  $subparms = array();
@@ -182,35 +230,69 @@ final class products_resultset
     }
 
 	if( isset($obj['fieldid']) && $obj['fieldid'] > 0 && isset($obj['fieldval']) && $obj['fieldval'] != '' ) {
+	  // add a default field expression
 	  $fieldid = $obj['fieldid'];
 	  $fieldval = $obj['fieldval'];
+	  $obj->add_field_expr($fieldid,$fieldval);
+	}
 
+	$suffix = 'A';
+	foreach( $obj->get_field_exprs() as $fieldid => $fieldval ) {
 	  if( $fieldval == '::null::' ) {
 		// handle a case where a field is not set for a product.
-		$joins[] = cms_db_prefix().'module_products_fieldvals FVA ON C.id = FVA.product_id AND FVA.fielddef_id = ?';
-		$where[] = '(FVA.value IS NULL)';
+		$joins[] = cms_db_prefix()."module_products_fieldvals FV{$suffix} ON C.id = FV{$suffix}.product_id AND FVA.fielddef_id = ?";
+		$where[] = "(FV{$suffix}.value IS NULL)";
 		array_unshift($qparms,$fieldid);
 	  }
 	  else if( $fieldval == '::notnull::' ) {
 		// handle the case where a field is set for a product, but we don't care about the value.
-		$joins[] = cms_db_prefix().'module_products_fieldvals FVA ON C.id = FVA.product_id AND FVA.fielddef_id = ?';
-		$where[] = '(FVA.value != \'\')';
+		$joins[] = cms_db_prefix()."module_products_fieldvals FV{$suffix} ON C.id = FV{$suffix}.product_id AND FV{$suffix}.fielddef_id = ?";
+		$where[] = "(FV{$suffix}.value != \'\')";
 		array_unshift($qparms,$fieldid);
 	  }
+	  else if( strpos($fieldval,':') !== FALSE ) {
+		// it's a min:max cast expression.
+		list($min,$max) = explode(':',$fieldval,2);
+		$min = trim($min); $max = trim($max);
+		if( $min && $max ) {
+		  $min = floatval($min);
+		  $max = floatval($max);
+		  $joins[] = cms_db_prefix()."module_products_fieldvals FV{$suffix} ON C.id = FV{$suffix}.product_id AND FV{$suffix}.fielddef_id = ?";
+		  $where[] = "(CAST(FV{$suffix}.value AS DECIMAL(12,3)) BETWEEN ? AND ?)";
+		  array_unshift($qparms,$fieldid);
+		  $qparms[] = $min;
+		  $qparms[] = $max;
+		}
+		elseif ( $min ) {
+		  $min = floatval($min);
+		  $joins[] = cms_db_prefix()."module_products_fieldvals FV{$suffix} ON C.id = FV{$suffix}.product_id AND FV{$suffix}.fielddef_id = ?";
+		  $where[] = "(CAST(FV{$suffix}.value AS DECIMAL(12,3)) >= ?)";
+		  array_unshift($qparms,$fieldid);
+		  $qparms[] = $min;
+		}
+		elseif ( $max ) {
+		  $max = floatval($max);
+		  $joins[] = cms_db_prefix()."module_products_fieldvals FV{$suffix} ON C.id = FV{$suffix}.product_id AND FV{$suffix}.fielddef_id = ?";
+		  $where[] = "(CAST(FV{$suffix}.value AS DECIMAL(12,3)) <= ?)";
+		  array_unshift($qparms,$fieldid);
+		  $qparms[] = $max;
+		}
+	  }
 	  else {
 		// limit results to all of the items that have this field, and field value.
-		$joins[] = cms_db_prefix().'module_products_fieldvals FVA ON C.id = FVA.product_id AND FVA.fielddef_id = ?';
+		$joins[] = cms_db_prefix()."module_products_fieldvals FV{$suffix} ON C.id = FV{$suffix}.product_id AND FV{$suffix}.fielddef_id = ?";
 		if( strpos($fieldval,'*') !== FALSE || strpos($fieldval,'%') !== FALSE ) {
-		  $where[] = '(FVA.value LIKE ?)';
+		  $where[] = "(FV{$suffix}.value LIKE ?)";
 		  array_unshift($qparms,$fieldid);
-		  $qparms[] = str_replace('*','%',$fieldval);
+		  $qparms[] = $this->_wildcard($fieldval);
 		}
 		else {
-		  $where[] = '(FVA.value = ?)';
+		  $where[] = "(FV{$suffix}.value = ?)";
 		  array_unshift($qparms,$fieldid);
 		  $qparms[] = $fieldval;
 		}
 	  }
+	  $suffix++;
 	}
 
 	$sortby = $obj['sortby'];
@@ -234,8 +316,10 @@ final class products_resultset
 	//
 	// build the query now.
 	//
+	$expr = ' AND ';
+	if( isset($obj['useor']) && $obj['useor'] ) $expr = ' OR ';
 	if( count($joins) ) $query .= ' LEFT JOIN '.implode(' LEFT JOIN ',$joins);
-	if( count($where) ) $query .= ' WHERE '.implode(' AND ',$where);
+	if( count($where) ) $query .= ' WHERE '.implode($expr,$where);
 	if( $obj['sorttype'] == '' ) {
 	  $query .= ' ORDER BY '.$sortby.' '.$obj['sortorder'];
 	}
@@ -488,12 +572,8 @@ final class products_resultset
 			$entry->value = unserialize($entry->value);
 		  }
 		  else if( $entry->type == 'image' ) {
-			if( $entry->value && file_exists(cms_join_path($filedir,'thumb_'.$entry->value)) ) {
-			  $entry->thumbnail = 'thumb_'.$entry->value;
-			}
-			if( $entry->value && file_exists(cms_join_path($filedir,'preview_'.$entry->value)) ) {
-			  $entry->preview = 'preview_'.$entry->value;
-			}
+			if( $entry->value && file_exists(cms_join_path($filedir,'thumb_'.$entry->value)) ) $entry->thumbnail = 'thumb_'.$entry->value;
+			if( $entry->value && file_exists(cms_join_path($filedir,'preview_'.$entry->value)) ) $entry->preview = 'preview_'.$entry->value;
 		  }
 		  $entry->fielddef_id = $entry->id; // ??
 		  $fldarray[$entry->name] = $entry;
@@ -531,21 +611,15 @@ final class products_resultset
 
 	$pretty_url = '';
 	$parms = array();
-	if( $this->_notpretty != '' ) {
-	  $parms['notpretty'] = $this->_notpretty;
-	}
-	if( product_utils::can_do_pretty('details',$parms) ) {
-	  $pretty_url = product_ops::pretty_url($onerow->id,$this->detailpage);
-	}
+	if( $this->_notpretty != '' ) $parms['notpretty'] = $this->_notpretty;
+	if( product_utils::can_do_pretty('details',$parms) ) $pretty_url = product_ops::pretty_url($onerow->id,$this->detailpage);
 
 	$parms = array();
 	$parms['productid'] = $onerow->id;
 	if( $this->_detailpage ) $parms['detailpage'] = $this->_detailpage;
 	if( $this->_detailtemplate ) $parms['detailtemplate'] = $this->_detailtemplate;
 	$onerow->detail_url = $module->create_url('prod','details',$this->detailpage,$parms,false,false,$pretty_url);
-	if( $onerow->hierarchy_id ) {
-	  $onerow->breadcrumb = hierarchy_ops::get_breadcrumb('cntnt01',$onerow->hierarchy_id,$this->hierpage);
-	}
+	if( $onerow->hierarchy_id ) $onerow->breadcrumb = hierarchy_ops::get_breadcrumb('cntnt01',$onerow->hierarchy_id,$this->hierpage);
 
 	return $onerow;
   } // function
