@@ -438,11 +438,17 @@ if( version_compare($oldversion,'2.19') < 0 )
 	$dict->ExecuteSQLArray($sqlarray);
   }
 
-if( version_compare($oldversion,'2.19.2') < 0 ) 
-  {
-	$query = 'ALTER TABLE '.cms_db_prefix().'module_products_fieldvals ADD PRIMARY KEY (product_id,fielddef_id)';
-	$db->Execute($query);
-  }
+if( version_compare($oldversion,'2.19.2') < 0 ) {
+  $query = 'ALTER TABLE '.cms_db_prefix().'module_products_fieldvals ADD PRIMARY KEY (product_id,fielddef_id)';
+  $db->Execute($query);
+}
+
+if( version_compare($oldversion,'2.19.10') < 0 ) {
+  $dict = NewDataDictionary($db);
+  $sqlarray = $dict->CreateIndexSQL('products_product_cats',cms_db_prefix().'module_products_product_categories','product_id,category_id',
+									array('UNIQUE'=>1));
+  $dict->ExecuteSQLArray($sqlarray);
+}
 
 // EOF
 ?>
